# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_steaminput.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ewebuimessages_steaminput.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"\x85\x07\n<CSteamInputService_ControllerButtonStateChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x0f\n\x07\x64pad_up\x18\x02 \x01(\x08\x12\x11\n\tdpad_down\x18\x03 \x01(\x08\x12\x11\n\tdpad_left\x18\x04 \x01(\x08\x12\x12\n\ndpad_right\x18\x05 \x01(\x08\x12\x14\n\x0c\x62utton_south\x18\x06 \x01(\x08\x12\x13\n\x0b\x62utton_east\x18\x07 \x01(\x08\x12\x13\n\x0b\x62utton_west\x18\x08 \x01(\x08\x12\x14\n\x0c\x62utton_north\x18\t \x01(\x08\x12\x18\n\x10\x62utton_back_view\x18\n \x01(\x08\x12\x1c\n\x14\x62utton_start_options\x18\x0b \x01(\x08\x12\x14\n\x0c\x62utton_steam\x18\x0c \x01(\x08\x12\x1b\n\x13\x62utton_quick_access\x18\r \x01(\x08\x12\x1b\n\x13\x62utton_mute_capture\x18\x0e \x01(\x08\x12\x18\n\x10left_stick_click\x18\x0f \x01(\x08\x12\x18\n\x10left_stick_touch\x18\x10 \x01(\x08\x12\x1a\n\x12left_stick_deflect\x18\x11 \x01(\x08\x12\x19\n\x11right_stick_click\x18\x12 \x01(\x08\x12\x19\n\x11right_stick_touch\x18\x13 \x01(\x08\x12\x1b\n\x13right_stick_deflect\x18\x14 \x01(\x08\x12\x1d\n\x15\x63\x65nter_trackpad_touch\x18\x15 \x01(\x08\x12\x1d\n\x15\x63\x65nter_trackpad_click\x18\x16 \x01(\x08\x12\x1b\n\x13left_trackpad_touch\x18\x17 \x01(\x08\x12\x1b\n\x13left_trackpad_click\x18\x18 \x01(\x08\x12\x1c\n\x14right_trackpad_touch\x18\x19 \x01(\x08\x12\x1c\n\x14right_trackpad_click\x18\x1a \x01(\x08\x12\x13\n\x0bleft_bumper\x18\x1b \x01(\x08\x12\x14\n\x0cleft_trigger\x18\x1c \x01(\x08\x12\n\n\x02l4\x18\x1d \x01(\x08\x12\n\n\x02l5\x18\x1e \x01(\x08\x12\x10\n\x08left_aux\x18\x1f \x01(\x08\x12\x14\n\x0cright_bumper\x18  \x01(\x08\x12\x15\n\rright_trigger\x18! \x01(\x08\x12\n\n\x02r4\x18\" \x01(\x08\x12\n\n\x02r5\x18# \x01(\x08\x12\x11\n\tright_aux\x18$ \x01(\x08\")\n\x11\x43ontrollerVector2\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"4\n\x11\x43ontrollerVector3\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"B\n\x14\x43ontrollerQuaternion\x12\t\n\x01w\x18\x01 \x01(\x02\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02\"E\n\x19\x43ontrollerGyroEulerAngles\x12\r\n\x05pitch\x18\x01 \x01(\x02\x12\x0b\n\x03yaw\x18\x02 \x01(\x02\x12\x0c\n\x04roll\x18\x03 \x01(\x02\"\x9e\x03\n9CSteamInputService_ControllerAxesStateChange_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12)\n\rjoystick_left\x18\x02 \x01(\x0b\x32\x12.ControllerVector2\x12*\n\x0ejoystick_right\x18\x03 \x01(\x0b\x32\x12.ControllerVector2\x12)\n\rtrackpad_left\x18\x04 \x01(\x0b\x32\x12.ControllerVector2\x12*\n\x0etrackpad_right\x18\x05 \x01(\x0b\x32\x12.ControllerVector2\x12+\n\x0ftrackpad_center\x18\x06 \x01(\x0b\x32\x12.ControllerVector2\x12\x1e\n\x16trackpad_pressure_left\x18\x07 \x01(\x02\x12\x1f\n\x17trackpad_pressure_right\x18\x08 \x01(\x02\x12\x14\n\x0ctrigger_left\x18\t \x01(\x02\x12\x15\n\rtrigger_right\x18\n \x01(\x02\"\x8f\x02\n5CSteamInputService_GyroQuaternionChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12\x32\n\x13gyro_raw_quaternion\x18\x03 \x01(\x0b\x32\x15.ControllerQuaternion\x12\x37\n\x18gyro_filtered_quaternion\x18\x04 \x01(\x0b\x32\x15.ControllerQuaternion\x12\x1d\n\x15imu_sensor_delta_time\x18\x05 \x01(\r\x12\x1d\n\x15\x65stimated_packet_rate\x18\x06 \x01(\r\"\xcc\x01\n0CSteamInputService_GyroSpeedChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12\x32\n\x0egyro_raw_speed\x18\x03 \x01(\x0b\x32\x1a.ControllerGyroEulerAngles\x12\x37\n\x13gyro_filtered_speed\x18\x04 \x01(\x0b\x32\x1a.ControllerGyroEulerAngles\"\xc4\x01\n8CSteamInputService_GyroAccelerometerChanged_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12+\n\x0f\x61\x63\x63\x65leromter_1g\x18\x04 \x01(\x0b\x32\x12.ControllerVector3\x12.\n\x12trusted_gravity_1g\x18\x05 \x01(\x0b\x32\x12.ControllerVector3\"\xb1\x01\n/CSteamInputService_GyroCalibration_Notification\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\timu_index\x18\x02 \x01(\r\x12\x1a\n\x12\x61\x63\x63\x65leromter_noise\x18\x03 \x01(\x02\x12\x17\n\x0fgyroscope_noise\x18\x04 \x01(\x02\x12\x1c\n\x14\x63\x61libration_progress\x18\x05 \x01(\x02\"]\n.CSteamInputService_ControllerStateFlow_Request\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\r\x12\x11\n\tflow_mode\x18\x02 \x01(\r\"1\n/CSteamInputService_ControllerStateFlow_Response\"h\n\x14\x43\x43ontrollerOriginKey\x12\x17\n\x0f\x63ontroller_type\x18\x01 \x01(\x05\x12\x18\n\x10\x63ontroller_style\x18\x02 \x01(\x05\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\r\n\x05input\x18\x04 \x01(\x05\"^\n\x1e\x43\x43ontrollerAccessibilityString\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.CControllerOriginKey\x12\x18\n\x10localized_string\x18\x02 \x01(\t\";\n9CSteamInputService_ControllerAccessibilityStrings_Request\"n\n:CSteamInputService_ControllerAccessibilityStrings_Response\x12\x30\n\x07strings\x18\x01 \x03(\x0b\x32\x1f.CControllerAccessibilityString2\xb8\x08\n\x11SteamInputManager\x12k\n\x18NotifyButtonStateChanged\x12=.CSteamInputService_ControllerButtonStateChanged_Notification\x1a\x10.WebUINoResponse\x12\x66\n\x16NotifyAxesStateChanged\x12:.CSteamInputService_ControllerAxesStateChange_Notification\x1a\x10.WebUINoResponse\x12l\n NotifyGyroQuaternionStateChanged\x12\x36.CSteamInputService_GyroQuaternionChanged_Notification\x1a\x10.WebUINoResponse\x12\x62\n\x1bNotifyGyroSpeedStateChanged\x12\x31.CSteamInputService_GyroSpeedChanged_Notification\x1a\x10.WebUINoResponse\x12r\n#NotifyGyroAccelerometerStateChanged\x12\x39.CSteamInputService_GyroAccelerometerChanged_Notification\x1a\x10.WebUINoResponse\x12g\n!NotifyGyroCalibrationStateChanged\x12\x30.CSteamInputService_GyroCalibration_Notification\x1a\x10.WebUINoResponse\x12}\n\x18StartControllerStateFlow\x12/.CSteamInputService_ControllerStateFlow_Request\x1a\x30.CSteamInputService_ControllerStateFlow_Response\x12{\n\x16\x45ndControllerStateFlow\x12/.CSteamInputService_ControllerStateFlow_Request\x1a\x30.CSteamInputService_ControllerStateFlow_Response\x12\x9c\x01\n!GetControllerAccessibilityStrings\x12:.CSteamInputService_ControllerAccessibilityStrings_Request\x1a;.CSteamInputService_ControllerAccessibilityStrings_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_steaminput_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STEAMINPUTMANAGER._options = None
  _STEAMINPUTMANAGER._serialized_options = b'\200\227\"\002'
  _CSTEAMINPUTSERVICE_CONTROLLERBUTTONSTATECHANGED_NOTIFICATION._serialized_start=87
  _CSTEAMINPUTSERVICE_CONTROLLERBUTTONSTATECHANGED_NOTIFICATION._serialized_end=988
  _CONTROLLERVECTOR2._serialized_start=990
  _CONTROLLERVECTOR2._serialized_end=1031
  _CONTROLLERVECTOR3._serialized_start=1033
  _CONTROLLERVECTOR3._serialized_end=1085
  _CONTROLLERQUATERNION._serialized_start=1087
  _CONTROLLERQUATERNION._serialized_end=1153
  _CONTROLLERGYROEULERANGLES._serialized_start=1155
  _CONTROLLERGYROEULERANGLES._serialized_end=1224
  _CSTEAMINPUTSERVICE_CONTROLLERAXESSTATECHANGE_NOTIFICATION._serialized_start=1227
  _CSTEAMINPUTSERVICE_CONTROLLERAXESSTATECHANGE_NOTIFICATION._serialized_end=1641
  _CSTEAMINPUTSERVICE_GYROQUATERNIONCHANGED_NOTIFICATION._serialized_start=1644
  _CSTEAMINPUTSERVICE_GYROQUATERNIONCHANGED_NOTIFICATION._serialized_end=1915
  _CSTEAMINPUTSERVICE_GYROSPEEDCHANGED_NOTIFICATION._serialized_start=1918
  _CSTEAMINPUTSERVICE_GYROSPEEDCHANGED_NOTIFICATION._serialized_end=2122
  _CSTEAMINPUTSERVICE_GYROACCELEROMETERCHANGED_NOTIFICATION._serialized_start=2125
  _CSTEAMINPUTSERVICE_GYROACCELEROMETERCHANGED_NOTIFICATION._serialized_end=2321
  _CSTEAMINPUTSERVICE_GYROCALIBRATION_NOTIFICATION._serialized_start=2324
  _CSTEAMINPUTSERVICE_GYROCALIBRATION_NOTIFICATION._serialized_end=2501
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_REQUEST._serialized_start=2503
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_REQUEST._serialized_end=2596
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_RESPONSE._serialized_start=2598
  _CSTEAMINPUTSERVICE_CONTROLLERSTATEFLOW_RESPONSE._serialized_end=2647
  _CCONTROLLERORIGINKEY._serialized_start=2649
  _CCONTROLLERORIGINKEY._serialized_end=2753
  _CCONTROLLERACCESSIBILITYSTRING._serialized_start=2755
  _CCONTROLLERACCESSIBILITYSTRING._serialized_end=2849
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_REQUEST._serialized_start=2851
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_REQUEST._serialized_end=2910
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_RESPONSE._serialized_start=2912
  _CSTEAMINPUTSERVICE_CONTROLLERACCESSIBILITYSTRINGS_RESPONSE._serialized_end=3022
  _STEAMINPUTMANAGER._serialized_start=3025
  _STEAMINPUTMANAGER._serialized_end=4105
_builder.BuildServices(DESCRIPTOR, 'webuimessages_steaminput_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_hardwareupdate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"webuimessages_hardwareupdate.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"\"\n CHardwareUpdate_GetState_Request\"_\n!CHardwareUpdate_GetState_Response\x12\x1c\n\x14is_updater_supported\x18\x01 \x01(\x08\x12\x1c\n\x14has_seen_controllers\x18\x02 \x01(\x08\"+\n)CHardwareUpdate_StateChanged_Notification\")\n\'CHardwareUpdate_CheckForUpdates_Request\"\x7f\n\x1b\x43MsgAvailableHardwareUpdate\x12\r\n\x05\x65type\x18\x01 \x01(\r\x12\x13\n\x0bhardware_id\x18\x02 \x01(\r\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x12\n\ncurrent_ts\x18\x04 \x01(\t\x12\x11\n\tupdate_ts\x18\x05 \x01(\t\"Y\n(CHardwareUpdate_CheckForUpdates_Response\x12-\n\x07updates\x18\x01 \x03(\x0b\x32\x1c.CMsgAvailableHardwareUpdate\"7\n\x1e\x43HardwareUpdate_Update_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\"!\n\x1f\x43HardwareUpdate_Update_Response\"?\n+CHardwareUpdate_UpdateProgress_Notification\x12\x10\n\x08progress\x18\x01 \x01(\x05\"1\n/CHardwareUpdate_UpdateStateChanged_Notification2\xaa\x04\n\x0eHardwareUpdate\x12Q\n\x08GetState\x12!.CHardwareUpdate_GetState_Request\x1a\".CHardwareUpdate_GetState_Response\x12R\n\x12NotifyStateChanged\x12*.CHardwareUpdate_StateChanged_Notification\x1a\x10.WebUINoResponse\x12\x66\n\x0f\x43heckForUpdates\x12(.CHardwareUpdate_CheckForUpdates_Request\x1a).CHardwareUpdate_CheckForUpdates_Response\x12K\n\x06Update\x12\x1f.CHardwareUpdate_Update_Request\x1a .CHardwareUpdate_Update_Response\x12V\n\x14NotifyUpdateProgress\x12,.CHardwareUpdate_UpdateProgress_Notification\x1a\x10.WebUINoResponse\x12^\n\x18NotifyUpdateStateChanged\x12\x30.CHardwareUpdate_UpdateStateChanged_Notification\x1a\x10.WebUINoResponse\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_hardwareupdate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _HARDWAREUPDATE._options = None
  _HARDWAREUPDATE._serialized_options = b'\200\227\"\001'
  _CHARDWAREUPDATE_GETSTATE_REQUEST._serialized_start=103
  _CHARDWAREUPDATE_GETSTATE_REQUEST._serialized_end=137
  _CHARDWAREUPDATE_GETSTATE_RESPONSE._serialized_start=139
  _CHARDWAREUPDATE_GETSTATE_RESPONSE._serialized_end=234
  _CHARDWAREUPDATE_STATECHANGED_NOTIFICATION._serialized_start=236
  _CHARDWAREUPDATE_STATECHANGED_NOTIFICATION._serialized_end=279
  _CHARDWAREUPDATE_CHECKFORUPDATES_REQUEST._serialized_start=281
  _CHARDWAREUPDATE_CHECKFORUPDATES_REQUEST._serialized_end=322
  _CMSGAVAILABLEHARDWAREUPDATE._serialized_start=324
  _CMSGAVAILABLEHARDWAREUPDATE._serialized_end=451
  _CHARDWAREUPDATE_CHECKFORUPDATES_RESPONSE._serialized_start=453
  _CHARDWAREUPDATE_CHECKFORUPDATES_RESPONSE._serialized_end=542
  _CHARDWAREUPDATE_UPDATE_REQUEST._serialized_start=544
  _CHARDWAREUPDATE_UPDATE_REQUEST._serialized_end=599
  _CHARDWAREUPDATE_UPDATE_RESPONSE._serialized_start=601
  _CHARDWAREUPDATE_UPDATE_RESPONSE._serialized_end=634
  _CHARDWAREUPDATE_UPDATEPROGRESS_NOTIFICATION._serialized_start=636
  _CHARDWAREUPDATE_UPDATEPROGRESS_NOTIFICATION._serialized_end=699
  _CHARDWAREUPDATE_UPDATESTATECHANGED_NOTIFICATION._serialized_start=701
  _CHARDWAREUPDATE_UPDATESTATECHANGED_NOTIFICATION._serialized_end=750
  _HARDWAREUPDATE._serialized_start=753
  _HARDWAREUPDATE._serialized_end=1307
_builder.BuildServices(DESCRIPTOR, 'webuimessages_hardwareupdate_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18webuimessages_base.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a google/protobuf/descriptor.proto\"\x11\n\x0fWebUINoResponse*\xa0\x01\n\x14\x45\x43lientExecutionSite\x12!\n\x1dk_EClientExecutionSiteInvalid\x10\x00\x12!\n\x1dk_EClientExecutionSiteSteamUI\x10\x01\x12#\n\x1fk_EClientExecutionSiteClientdll\x10\x02\x12\x1d\n\x19k_EClientExecutionSiteAny\x10\x03:}\n\x1cwebui_service_execution_site\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\xa2\x04 \x01(\x0e\x32\x15.EClientExecutionSite:\x1dk_EClientExecutionSiteSteamUI:{\n\x1bwebui_method_execution_site\x12\x1e.google.protobuf.MethodOptions\x18\xf0\xa2\x04 \x01(\x0e\x32\x15.EClientExecutionSite:\x1dk_EClientExecutionSiteInvalidB\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(webui_service_execution_site)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(webui_method_execution_site)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _ECLIENTEXECUTIONSITE._serialized_start=121
  _ECLIENTEXECUTIONSITE._serialized_end=281
  _WEBUINORESPONSE._serialized_start=101
  _WEBUINORESPONSE._serialized_end=118
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientmetrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.clientmetrics_pb2 as clientmetrics__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_clientmetrics.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x13\x63lientmetrics.proto\x1a\x0b\x65nums.proto\"\\\n#CClientMetrics_AppInterfaceCreation\x12\x13\n\x0braw_version\x18\x01 \x01(\t\x12 \n\x18requested_interface_type\x18\x02 \x01(\t\"j\n\'CClientMetrics_AppInterfaceMethodCounts\x12\x16\n\x0einterface_name\x18\x01 \x01(\t\x12\x13\n\x0bmethod_name\x18\x02 \x01(\t\x12\x12\n\ncall_count\x18\x03 \x01(\r\"\xe4\x01\n-CClientMetrics_AppInterfaceStats_Notification\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12@\n\x12interfaces_created\x18\x02 \x03(\x0b\x32$.CClientMetrics_AppInterfaceCreation\x12@\n\x0emethods_called\x18\x03 \x03(\x0b\x32(.CClientMetrics_AppInterfaceMethodCounts\x12\x1e\n\x16session_length_seconds\x18\x04 \x01(\r\"]\n&CClientMetrics_IPv6Connectivity_Result\x12\x17\n\x0fprotocol_tested\x18\x01 \x01(\r\x12\x1a\n\x12\x63onnectivity_state\x18\x02 \x01(\r\"\x98\x01\n,CClientMetrics_IPv6Connectivity_Notification\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x38\n\x07results\x18\x02 \x03(\x0b\x32\'.CClientMetrics_IPv6Connectivity_Result\x12\x1d\n\x15private_ip_is_rfc6598\x18\x03 \x01(\x08\"\xfb\x01\n+CClientMetrics_SteamPipeWorkStats_Operation\x12I\n\x04type\x18\x01 \x01(\x0e\x32\x18.ESteamPipeOperationType:!k_ESteamPipeOperationType_Invalid\x12\x0f\n\x07num_ops\x18\x02 \x01(\r\x12\x11\n\tnum_bytes\x18\x03 \x01(\x04\x12\x14\n\x0c\x62usy_time_ms\x18\x04 \x01(\x04\x12\x14\n\x0cidle_time_ms\x18\x05 \x01(\x04\x12\x17\n\x0fsum_run_time_ms\x18\x06 \x01(\x04\x12\x18\n\x10sum_wait_time_ms\x18\x07 \x01(\x04\"\xf5\x01\n.CClientMetrics_SteamPipeWorkStats_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12J\n\twork_type\x18\x03 \x01(\x0e\x32\x13.ESteamPipeWorkType:\"k_ESteamPipeClientWorkType_Invalid\x12@\n\noperations\x18\x04 \x03(\x0b\x32,.CClientMetrics_SteamPipeWorkStats_Operation\x12\x15\n\rhardware_type\x18\x05 \x01(\r\"\xc0\x03\n,CClientMetrics_ReportReactUsage_Notification\x12\x0f\n\x07product\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12G\n\x06routes\x18\x03 \x03(\x0b\x32\x37.CClientMetrics_ReportReactUsage_Notification.RouteData\x12O\n\ncomponents\x18\x04 \x03(\x0b\x32;.CClientMetrics_ReportReactUsage_Notification.ComponentData\x12I\n\x07\x61\x63tions\x18\x05 \x03(\x0b\x32\x38.CClientMetrics_ReportReactUsage_Notification.ActionData\x1a)\n\tRouteData\x12\r\n\x05route\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a\x31\n\rComponentData\x12\x11\n\tcomponent\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a+\n\nActionData\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xe5\x01\n-CClientMetrics_ReportClientError_Notification\x12\x0f\n\x07product\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x44\n\x06\x65rrors\x18\x03 \x03(\x0b\x32\x34.CClientMetrics_ReportClientError_Notification.Error\x1aL\n\x05\x45rror\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07\x63ontext\x18\x04 \x01(\t\"g\n+CClientMetrics_ClientBootstrap_Notification\x12\x38\n\x07summary\x18\x01 \x01(\x0b\x32\'.CClientMetrics_ClientBootstrap_Summary\"\xb7\x03\n)CClientMetrics_DownloadRates_Notification\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x43\n\x05stats\x18\x02 \x03(\x0b\x32\x34.CClientMetrics_DownloadRates_Notification.StatsInfo\x12\x17\n\x0fthrottling_kbps\x18\x03 \x01(\r\x12\x0f\n\x07os_type\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x65vice_type\x18\x05 \x01(\r\x1a\xf4\x01\n\tStatsInfo\x12\x13\n\x0bsource_type\x18\x01 \x01(\r\x12\x11\n\tsource_id\x18\x02 \x01(\r\x12\r\n\x05\x62ytes\x18\x03 \x01(\x04\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x14\n\x0cmicroseconds\x18\x05 \x01(\x04\x12\x11\n\tused_ipv6\x18\x06 \x01(\x08\x12\x0f\n\x07proxied\x18\x07 \x01(\x08\x12\x12\n\nused_http2\x18\x08 \x01(\x08\x12\x12\n\ncache_hits\x18\t \x01(\r\x12\x14\n\x0c\x63\x61\x63he_misses\x18\n \x01(\r\x12\x11\n\thit_bytes\x18\x0b \x01(\x04\x12\x12\n\nmiss_bytes\x18\x0c \x01(\x04\"\xa0\x02\n-CClientMetrics_ContentValidation_Notification\x12\x19\n\x11validation_result\x18\x01 \x01(\x05\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x14\n\x0cstaged_files\x18\x03 \x01(\x08\x12\x16\n\x0euser_initiated\x18\x04 \x01(\x08\x12\x11\n\tearly_out\x18\x05 \x01(\x08\x12\x16\n\x0e\x63hunks_scanned\x18\x06 \x01(\r\x12\x16\n\x0e\x63hunks_corrupt\x18\x07 \x01(\r\x12\x15\n\rbytes_scanned\x18\x08 \x01(\x04\x12\x1b\n\x13\x63hunk_bytes_corrupt\x18\t \x01(\x04\x12\x1f\n\x17total_file_size_corrupt\x18\n \x01(\x04\"\xe0\x04\n-CClientMetrics_CloudAppSyncStats_Notification\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rplatform_type\x18\x02 \x01(\r\x12\x0f\n\x07preload\x18\x03 \x01(\x08\x12\x1b\n\x13\x62locking_app_launch\x18\x04 \x01(\x08\x12\x16\n\x0e\x66iles_uploaded\x18\x05 \x01(\r\x12\x18\n\x10\x66iles_downloaded\x18\x06 \x01(\r\x12\x15\n\rfiles_deleted\x18\x07 \x01(\r\x12\x16\n\x0e\x62ytes_uploaded\x18\x08 \x01(\x04\x12\x18\n\x10\x62ytes_downloaded\x18\t \x01(\x04\x12\x16\n\x0emicrosec_total\x18\n \x01(\x04\x12\x1c\n\x14microsec_init_caches\x18\x0b \x01(\x04\x12\x1f\n\x17microsec_validate_state\x18\x0c \x01(\x04\x12\x1a\n\x12microsec_ac_launch\x18\r \x01(\x04\x12#\n\x1bmicrosec_ac_prep_user_files\x18\x0e \x01(\x04\x12\x18\n\x10microsec_ac_exit\x18\x0f \x01(\x04\x12 \n\x18microsec_build_sync_list\x18\x10 \x01(\x04\x12\x1d\n\x15microsec_delete_files\x18\x11 \x01(\x04\x12\x1f\n\x17microsec_download_files\x18\x12 \x01(\x04\x12\x1d\n\x15microsec_upload_files\x18\x13 \x01(\x04\x12\x15\n\rhardware_type\x18\x14 \x01(\r\x12\x15\n\rfiles_managed\x18\x15 \x01(\r\"\x8a\x01\n:CClientMetrics_ContentDownloadResponse_Counts_Notification\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.CClientMetrics_ContentDownloadResponse_Hosts\"\xe8\x02\n,CClientMetrics_ReportClientArgs_Notification\x12\x13\n\x0b\x63lient_args\x18\x01 \x03(\t\x12#\n\x1bgpu_webview_regkey_disabled\x18\x02 \x01(\x08\x12\x1b\n\x13suppress_gpu_chrome\x18\x03 \x01(\x08\x12\x1d\n\x15\x62rowser_not_supported\x18\x04 \x01(\x08\x12&\n\x1ehw_accel_video_regkey_disabled\x18\x05 \x01(\x08\x12\x19\n\x11mini_mode_enabled\x18\x06 \x01(\x08\x12\x1b\n\x13\x66ps_counter_enabled\x18\x07 \x01(\x08\x12*\n\"library_low_bandwidth_mode_enabled\x18\x08 \x01(\x08\x12%\n\x1dlibrary_low_perf_mode_enabled\x18\t \x01(\x08\x12\x0f\n\x07gr_mode\x18\n \x01(\x05\"\xc6\x01\n,CClientMetrics_ReportLinuxStats_Notification\x12\x1b\n\x13glibc_version_major\x18\x01 \x01(\x05\x12\x1b\n\x13glibc_version_minor\x18\x02 \x01(\x05\x12\x14\n\x0c\x61\x63\x63ount_type\x18\x03 \x01(\x05\x12\x15\n\rlauncher_type\x18\x04 \x01(\x05\x12\x19\n\x11game_server_appid\x18\x05 \x01(\x05\x12\x14\n\x0cprocess_name\x18\x06 \x01(\t\"\x86\x02\n7CClientMetrics_ReportAccessibilitySettings_Notification\x12&\n\x1e\x61\x63\x63\x65ssibility_desktop_ui_scale\x18\x01 \x01(\x02\x12+\n#accessibility_screen_reader_enabled\x18\x02 \x01(\x08\x12(\n accessibility_high_contrast_mode\x18\x03 \x01(\x08\x12#\n\x1b\x61\x63\x63\x65ssibility_reduce_motion\x18\x04 \x01(\x08\x12\'\n\x1f\x61\x63\x63\x65ssibility_color_filter_name\x18\x05 \x01(\t\"\xad\x01\n%CClientMetrics_ClipShare_Notification\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12@\n\x0cshare_method\x18\x02 \x01(\x0e\x32\x11.EClipShareMethod:\x17k_EClipShareMethod_Chat\x12\x0f\n\x07seconds\x18\x03 \x01(\x02\x12\r\n\x05\x62ytes\x18\x04 \x01(\x04\x12\x0e\n\x06gameid\x18\x05 \x01(\x06\"\x83\x04\n%CClientMetrics_ClipRange_Notification\x12U\n\x15original_range_method\x18\x01 \x01(\x0e\x32\x11.EClipRangeMethod:#k_EClipRangeMethod_CreateClipButton\x12G\n\x05start\x18\x02 \x01(\x0b\x32\x38.CClientMetrics_ClipRange_Notification.RelativeRangeEdge\x12\x45\n\x03\x65nd\x18\x03 \x01(\x0b\x32\x38.CClientMetrics_ClipRange_Notification.RelativeRangeEdge\x12\x0f\n\x07seconds\x18\x04 \x01(\x02\x12\x0e\n\x06gameid\x18\x05 \x01(\x06\x1a\xd1\x01\n\x11RelativeRangeEdge\x12U\n\x15original_range_method\x18\x01 \x01(\x0e\x32\x11.EClipRangeMethod:#k_EClipRangeMethod_CreateClipButton\x12S\n\x13latest_range_method\x18\x02 \x01(\x0e\x32\x11.EClipRangeMethod:#k_EClipRangeMethod_CreateClipButton\x12\x10\n\x08\x64\x65lta_ms\x18\x03 \x01(\x05\"\xbf\x01\n,CClientMetrics_EndGameRecording_Notification\x12I\n\x0erecording_type\x18\x01 \x01(\x0e\x32\x13.EGameRecordingType:\x1ck_EGameRecordingType_Unknown\x12\x0f\n\x07seconds\x18\x02 \x01(\x02\x12\r\n\x05\x62ytes\x18\x03 \x01(\x04\x12\x0e\n\x06gameid\x18\x04 \x01(\x06\x12\x14\n\x0cinstant_clip\x18\x05 \x01(\x08\"\xd8\x02\n+CClientMetrics_GamePerformance_Notification\x12M\n\x07reports\x18\x01 \x03(\x0b\x32<.CClientMetrics_GamePerformance_Notification.FrameRateReport\x1a\xd9\x01\n\x0f\x46rameRateReport\x12\x0e\n\x06gameid\x18\x01 \x01(\x06\x12\x12\n\nframe_rate\x18\x02 \x01(\r\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\x12\r\n\x05model\x18\x04 \x01(\t\x12\x15\n\rdx_video_card\x18\x05 \x01(\t\x12\x13\n\x0b\x64x_vendorid\x18\x06 \x01(\x05\x12\x13\n\x0b\x64x_deviceid\x18\x07 \x01(\x05\x12\x0f\n\x07num_gpu\x18\x08 \x01(\r\x12\x12\n\nsystem_ram\x18\t \x01(\x04\x12\x17\n\x0fsession_seconds\x18\n \x01(\x05*q\n\x12\x45SteamPipeWorkType\x12&\n\"k_ESteamPipeClientWorkType_Invalid\x10\x00\x12\x33\n/k_ESteamPipeClientWorkType_StageFromChunkStores\x10\x01*\xbb\x01\n\x17\x45SteamPipeOperationType\x12%\n!k_ESteamPipeOperationType_Invalid\x10\x00\x12(\n$k_ESteamPipeOperationType_DecryptCPU\x10\x01\x12&\n\"k_ESteamPipeOperationType_DiskRead\x10\x02\x12\'\n#k_ESteamPipeOperationType_DiskWrite\x10\x03*\xd6\x01\n\x10\x45\x43lipShareMethod\x12\x1b\n\x17k_EClipShareMethod_Chat\x10\x01\x12 \n\x1ck_EClipShareMethod_Clipboard\x10\x02\x12\x1b\n\x17k_EClipShareMethod_File\x10\x03\x12\x1f\n\x1bk_EClipShareMethod_SendClip\x10\x04\x12\"\n\x1ek_EClipShareMethod_SaveToMedia\x10\x05\x12!\n\x1dk_EClipShareMethod_CreateLink\x10\x06*\x90\x02\n\x10\x45\x43lipRangeMethod\x12\'\n#k_EClipRangeMethod_CreateClipButton\x10\x01\x12 \n\x1ck_EClipRangeMethod_Highlight\x10\x02\x12&\n\"k_EClipRangeMethod_BeginEndButtons\x10\x03\x12\"\n\x1ek_EClipRangeMethod_ContextMenu\x10\x04\x12\x1b\n\x17k_EClipRangeMethod_Drag\x10\x05\x12!\n\x1dk_EClipRangeMethod_EntireClip\x10\x06\x12%\n!k_EClipRangeMethod_PhaseRecording\x10\x07\x32\xd3\x0b\n\rClientMetrics\x12\\\n\x1d\x43lientAppInterfaceStatsReport\x12..CClientMetrics_AppInterfaceStats_Notification\x1a\x0b.NoResponse\x12Z\n\x1c\x43lientIPv6ConnectivityReport\x12-.CClientMetrics_IPv6Connectivity_Notification\x1a\x0b.NoResponse\x12X\n\x18SteamPipeWorkStatsReport\x12/.CClientMetrics_SteamPipeWorkStats_Notification\x1a\x0b.NoResponse\x12N\n\x10ReportReactUsage\x12-.CClientMetrics_ReportReactUsage_Notification\x1a\x0b.NoResponse\x12P\n\x11ReportClientError\x12..CClientMetrics_ReportClientError_Notification\x1a\x0b.NoResponse\x12R\n\x15\x43lientBootstrapReport\x12,.CClientMetrics_ClientBootstrap_Notification\x1a\x0b.NoResponse\x12T\n\x19\x43lientDownloadRatesReport\x12*.CClientMetrics_DownloadRates_Notification\x1a\x0b.NoResponse\x12\\\n\x1d\x43lientContentValidationReport\x12..CClientMetrics_ContentValidation_Notification\x1a\x0b.NoResponse\x12V\n\x17\x43lientCloudAppSyncStats\x12..CClientMetrics_CloudAppSyncStats_Notification\x1a\x0b.NoResponse\x12l\n ClientDownloadResponseCodeCounts\x12;.CClientMetrics_ContentDownloadResponse_Counts_Notification\x1a\x0b.NoResponse\x12N\n\x10ReportClientArgs\x12-.CClientMetrics_ReportClientArgs_Notification\x1a\x0b.NoResponse\x12N\n\x10ReportLinuxStats\x12-.CClientMetrics_ReportLinuxStats_Notification\x1a\x0b.NoResponse\x12\x64\n\x1bReportAccessibilitySettings\x12\x38.CClientMetrics_ReportAccessibilitySettings_Notification\x1a\x0b.NoResponse\x12\x46\n\x0fReportClipShare\x12&.CClientMetrics_ClipShare_Notification\x1a\x0b.NoResponse\x12\x46\n\x0fReportClipRange\x12&.CClientMetrics_ClipRange_Notification\x1a\x0b.NoResponse\x12T\n\x16ReportEndGameRecording\x12-.CClientMetrics_EndGameRecording_Notification\x1a\x0b.NoResponse\x12R\n\x15ReportGamePerformance\x12,.CClientMetrics_GamePerformance_Notification\x1a\x0b.NoResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientmetrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ESTEAMPIPEWORKTYPE._serialized_start=5653
  _ESTEAMPIPEWORKTYPE._serialized_end=5766
  _ESTEAMPIPEOPERATIONTYPE._serialized_start=5769
  _ESTEAMPIPEOPERATIONTYPE._serialized_end=5956
  _ECLIPSHAREMETHOD._serialized_start=5959
  _ECLIPSHAREMETHOD._serialized_end=6173
  _ECLIPRANGEMETHOD._serialized_start=6176
  _ECLIPRANGEMETHOD._serialized_end=6448
  _CCLIENTMETRICS_APPINTERFACECREATION._serialized_start=131
  _CCLIENTMETRICS_APPINTERFACECREATION._serialized_end=223
  _CCLIENTMETRICS_APPINTERFACEMETHODCOUNTS._serialized_start=225
  _CCLIENTMETRICS_APPINTERFACEMETHODCOUNTS._serialized_end=331
  _CCLIENTMETRICS_APPINTERFACESTATS_NOTIFICATION._serialized_start=334
  _CCLIENTMETRICS_APPINTERFACESTATS_NOTIFICATION._serialized_end=562
  _CCLIENTMETRICS_IPV6CONNECTIVITY_RESULT._serialized_start=564
  _CCLIENTMETRICS_IPV6CONNECTIVITY_RESULT._serialized_end=657
  _CCLIENTMETRICS_IPV6CONNECTIVITY_NOTIFICATION._serialized_start=660
  _CCLIENTMETRICS_IPV6CONNECTIVITY_NOTIFICATION._serialized_end=812
  _CCLIENTMETRICS_STEAMPIPEWORKSTATS_OPERATION._serialized_start=815
  _CCLIENTMETRICS_STEAMPIPEWORKSTATS_OPERATION._serialized_end=1066
  _CCLIENTMETRICS_STEAMPIPEWORKSTATS_NOTIFICATION._serialized_start=1069
  _CCLIENTMETRICS_STEAMPIPEWORKSTATS_NOTIFICATION._serialized_end=1314
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION._serialized_start=1317
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION._serialized_end=1765
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION_ROUTEDATA._serialized_start=1628
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION_ROUTEDATA._serialized_end=1669
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION_COMPONENTDATA._serialized_start=1671
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION_COMPONENTDATA._serialized_end=1720
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION_ACTIONDATA._serialized_start=1722
  _CCLIENTMETRICS_REPORTREACTUSAGE_NOTIFICATION_ACTIONDATA._serialized_end=1765
  _CCLIENTMETRICS_REPORTCLIENTERROR_NOTIFICATION._serialized_start=1768
  _CCLIENTMETRICS_REPORTCLIENTERROR_NOTIFICATION._serialized_end=1997
  _CCLIENTMETRICS_REPORTCLIENTERROR_NOTIFICATION_ERROR._serialized_start=1921
  _CCLIENTMETRICS_REPORTCLIENTERROR_NOTIFICATION_ERROR._serialized_end=1997
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_NOTIFICATION._serialized_start=1999
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_NOTIFICATION._serialized_end=2102
  _CCLIENTMETRICS_DOWNLOADRATES_NOTIFICATION._serialized_start=2105
  _CCLIENTMETRICS_DOWNLOADRATES_NOTIFICATION._serialized_end=2544
  _CCLIENTMETRICS_DOWNLOADRATES_NOTIFICATION_STATSINFO._serialized_start=2300
  _CCLIENTMETRICS_DOWNLOADRATES_NOTIFICATION_STATSINFO._serialized_end=2544
  _CCLIENTMETRICS_CONTENTVALIDATION_NOTIFICATION._serialized_start=2547
  _CCLIENTMETRICS_CONTENTVALIDATION_NOTIFICATION._serialized_end=2835
  _CCLIENTMETRICS_CLOUDAPPSYNCSTATS_NOTIFICATION._serialized_start=2838
  _CCLIENTMETRICS_CLOUDAPPSYNCSTATS_NOTIFICATION._serialized_end=3446
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_COUNTS_NOTIFICATION._serialized_start=3449
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_COUNTS_NOTIFICATION._serialized_end=3587
  _CCLIENTMETRICS_REPORTCLIENTARGS_NOTIFICATION._serialized_start=3590
  _CCLIENTMETRICS_REPORTCLIENTARGS_NOTIFICATION._serialized_end=3950
  _CCLIENTMETRICS_REPORTLINUXSTATS_NOTIFICATION._serialized_start=3953
  _CCLIENTMETRICS_REPORTLINUXSTATS_NOTIFICATION._serialized_end=4151
  _CCLIENTMETRICS_REPORTACCESSIBILITYSETTINGS_NOTIFICATION._serialized_start=4154
  _CCLIENTMETRICS_REPORTACCESSIBILITYSETTINGS_NOTIFICATION._serialized_end=4416
  _CCLIENTMETRICS_CLIPSHARE_NOTIFICATION._serialized_start=4419
  _CCLIENTMETRICS_CLIPSHARE_NOTIFICATION._serialized_end=4592
  _CCLIENTMETRICS_CLIPRANGE_NOTIFICATION._serialized_start=4595
  _CCLIENTMETRICS_CLIPRANGE_NOTIFICATION._serialized_end=5110
  _CCLIENTMETRICS_CLIPRANGE_NOTIFICATION_RELATIVERANGEEDGE._serialized_start=4901
  _CCLIENTMETRICS_CLIPRANGE_NOTIFICATION_RELATIVERANGEEDGE._serialized_end=5110
  _CCLIENTMETRICS_ENDGAMERECORDING_NOTIFICATION._serialized_start=5113
  _CCLIENTMETRICS_ENDGAMERECORDING_NOTIFICATION._serialized_end=5304
  _CCLIENTMETRICS_GAMEPERFORMANCE_NOTIFICATION._serialized_start=5307
  _CCLIENTMETRICS_GAMEPERFORMANCE_NOTIFICATION._serialized_end=5651
  _CCLIENTMETRICS_GAMEPERFORMANCE_NOTIFICATION_FRAMERATEREPORT._serialized_start=5434
  _CCLIENTMETRICS_GAMEPERFORMANCE_NOTIFICATION_FRAMERATEREPORT._serialized_end=5651
  _CLIENTMETRICS._serialized_start=6451
  _CLIENTMETRICS._serialized_end=7942
_builder.BuildServices(DESCRIPTOR, 'steammessages_clientmetrics_pb2', globals())
# @@protoc_insertion_point(module_scope)



r"""
Listing and information about game servers through Steam

Filters
-------

.. note::
    Multiple filters can be joined to together (Eg. ``\app\730\white\1\empty\1``)

=========================== =========================================================================================================================
Filter code                 What it does
=========================== =========================================================================================================================
\\nor\\[x]                  A special filter, specifies that servers matching any of the following [x] conditions should not be returned
\\nand\\[x]                 A special filter, specifies that servers matching all of the following [x] conditions should not be returned
\\dedicated\\1              Servers running dedicated
\\secure\\1                 Servers using anti-cheat technology (VAC, but potentially others as well)
\\gamedir\\[mod]            Servers running the specified modification (ex. cstrike)
\\map\\[map]                Servers running the specified map (ex. cs_italy)
\\linux\\1                  Servers running on a Linux platform
\\password\\0               Servers that are not password protected
\\empty\\1                  Servers that are not empty
\\full\\1                   Servers that are not full
\\proxy\\1                  Servers that are spectator proxies
\\appid\\[appid]            Servers that are running game [appid]
\\napp\\[appid]             Servers that are NOT running game [appid] (This was introduced to block Left 4 Dead games from the Steam Server Browser)
\\noplayers\\1              Servers that are empty
\\white\\1                  Servers that are whitelisted
\\gametype\\[tag,...]       Servers with all of the given tag(s) in sv_tags
\\gamedata\\[tag,...]       Servers with all of the given tag(s) in their 'hidden' tags (L4D2)
\\gamedataor\\[tag,...]     Servers with any of the given tag(s) in their 'hidden' tags (L4D2)
\\name_match\\[hostname]    Servers with their hostname matching [hostname] (can use * as a wildcard)
\\version_match\\[version]  Servers running version [version] (can use * as a wildcard)
\\collapse_addr_hash\\1     Return only one server for each unique IP address matched
\\gameaddr\\[ip]            Return only servers on the specified IP address (port supported and optional)
=========================== =========================================================================================================================
"""
from steam.steamid import SteamID
from steam.core.msg import MsgProto
from steam.enums import EResult
from steam.enums.emsg import EMsg
from steam.utils import ip4_to_int, ip4_from_int, ip6_from_bytes
from steam.utils.proto import proto_to_dict
from steam.exceptions import SteamError


class GameServers(object):
    def __init__(self, *args, **kwargs):
        super(GameServers, self).__init__(*args, **kwargs)

        self.gameservers = SteamGameServers(self)  #: instance of :class:`SteamGameServers`


class SteamGameServers(object):
    def __init__(self, steam):
        self._s = steam

    def query(self, filter_text, max_servers=10, timeout=30, **kw):
        r"""
        Query game servers

        https://developer.valvesoftware.com/wiki/Master_Server_Query_Protocol

        .. note::
            When specifying ``filter_text`` use *raw strings* otherwise python won't treat backslashes
            as literal characters (e.g. ``query(r'\appid\730\white\1')``)

        :param filter_text: filter for servers
        :type  filter_text: str
        :param max_servers: (optional) number of servers to return
        :type  max_servers: int
        :param timeout: (optional) timeout for request in seconds
        :type  timeout: int
        :param app_id: (optional) app id
        :type  app_id: int
        :param geo_location_ip: (optional) ip (e.g. '1.2.3.4')
        :type  geo_location_ip: str
        :returns: list of servers, see below. (``None`` is returned steam doesn't respond)
        :rtype: :class:`list`, :class:`None`

        Sample response:

        .. code:: python

            [{'auth_players': 0, 'server_ip': '1.2.3.4', 'query_port': 27015},
             {'auth_players': 6, 'server_ip': '1:2:3:4::5', 'query_port': 27016},
             ...
            ]
        """
        if 'geo_location_ip' in kw:
            kw['geo_location_ip'] = ip4_to_int(kw['geo_location_ip'])

        kw['filter_text'] = filter_text
        kw['max_servers'] = max_servers

        resp = self._s.send_job_and_wait(MsgProto(EMsg.ClientGMSServerQuery),
                                         kw,
                                         timeout=timeout,
                                         )

        if resp is None:
            return None

        resp = proto_to_dict(resp)

        for server in resp['servers']:
            server.pop('deprecated_server_ip', None)  # no point returning this

            if 'v4' in server['server_ip']:
                server['server_ip'] = ip4_from_int(server['server_ip']['v4'])
            else:
                server['server_ip'] = ip6_from_bytes(server['server_ip']['v6'])

        return resp['servers']

    def get_server_list(self, filter_text, max_servers=10, timeout=20):
        """
        Get list of servers. Works similiarly to :meth:`query`, but the response has more details.

        :param filter_text: filter for servers
        :type  filter_text: str
        :param max_servers: (optional) number of servers to return
        :type  max_servers: int
        :param timeout: (optional) timeout for request in seconds
        :type  timeout: int
        :returns: list of servers, see below. (``None`` is returned steam doesn't respond)
        :rtype: :class:`list`, :class:`None`
        :raises: :class:`.SteamError`


        Sample response:

        .. code:: python

            [{'addr': '1.2.3.4:27067',
              'appid': 730,
              'bots': 0,
              'dedicated': True,
              'gamedir': 'csgo',
              'gameport': 27067,
              'gametype': 'valve_ds,empty,secure',
              'map': 'de_dust2',
              'max_players': 10,
              'name': 'Valve CS:GO Asia Server (srcdsXXX.XXX.XXX)',
              'os': 'l',
              'players': 0,
              'product': 'csgo',
              'region': 5,
              'secure': True,
              'steamid': SteamID(id=3279818759, type='AnonGameServer', universe='Public', instance=7011),
              'version': '1.35.4.0'}
            ]
        """
        resp = self._s.send_um_and_wait("GameServers.GetServerList#1",
                                        {
                                         "filter": filter_text,
                                         "limit": max_servers,
                                        },
                                        timeout=20,
                                        )

        if resp is None:
            return None
        if resp.header.eresult != EResult.OK:
            raise SteamError(resp.header.error_message, resp.header.eresult)

        resp = proto_to_dict(resp.body)

        if not resp:
            return []
        else:
            for server in resp['servers']:
                server['steamid'] = SteamID(server['steamid'])

            return resp['servers']

    def get_ips_from_steamids(self, server_steam_ids, timeout=30):
        """Resolve IPs from SteamIDs

        :param server_steam_ids: a list of steamids
        :type  server_steam_ids: list
        :param timeout: (optional) timeout for request in seconds
        :type  timeout: int
        :return: map of ips to steamids
        :rtype: dict
        :raises: :class:`.SteamError`

        Sample response:

        .. code:: python

            {SteamID(id=123456, type='AnonGameServer', universe='Public', instance=1234): '1.2.3.4:27060'}
        """
        resp = self._s.send_um_and_wait("GameServers.GetServerIPsBySteamID#1",
                                        {"server_steamids": server_steam_ids},
                                        timeout=timeout,
                                        )
        if resp is None:
            return None
        if resp.header.eresult != EResult.OK:
            raise SteamError(resp.header.error_message, resp.header.eresult)

        return {SteamID(server.steamid): server.addr for server in resp.body.servers}

    def get_steamids_from_ips(self, server_ips, timeout=30):
        """Resolve SteamIDs from IPs

        :param steam_ids: a list of ips (e.g. ``['1.2.3.4:27015',...]``)
        :type  steam_ids: list
        :param timeout: (optional) timeout for request in seconds
        :type  timeout: int
        :return: map of steamids to ips
        :rtype: dict
        :raises: :class:`.SteamError`

        Sample response:

        .. code:: python

            {'1.2.3.4:27060': SteamID(id=123456, type='AnonGameServer', universe='Public', instance=1234)}
        """
        resp = self._s.send_um_and_wait("GameServers.GetServerSteamIDsByIP#1",
                                        {"server_ips": server_ips},
                                        timeout=timeout,
                                        )
        if resp is None:
            return None
        if resp.header.eresult != EResult.OK:
            raise SteamError(resp.header.error_message, resp.header.eresult)

        return {server.addr: SteamID(server.steamid) for server in resp.body.servers}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parental_objects.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_parental_objects.proto\x1a\x0b\x65nums.proto\"0\n\x0bParentalApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nis_allowed\x18\x02 \x01(\x08\"R\n\x13ParentalPlaytimeDay\x12\x1c\n\x14\x61llowed_time_windows\x18\x01 \x01(\x04\x12\x1d\n\x15\x61llowed_daily_minutes\x18\x02 \x01(\r\"p\n\x1cParentalPlaytimeRestrictions\x12#\n\x1b\x61pply_playtime_restrictions\x18\x02 \x01(\x08\x12+\n\rplaytime_days\x18\x0f \x03(\x0b\x32\x14.ParentalPlaytimeDay\"j\n%ParentalTemporaryPlaytimeRestrictions\x12*\n\x0crestrictions\x18\x01 \x01(\x0b\x32\x14.ParentalPlaytimeDay\x12\x15\n\rrtime_expires\x18\x02 \x01(\r\"\x9d\x05\n\x10ParentalSettings\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x61pplist_base_id\x18\x02 \x01(\r\x12 \n\x18\x61pplist_base_description\x18\x03 \x01(\t\x12\"\n\x0c\x61pplist_base\x18\x04 \x03(\x0b\x32\x0c.ParentalApp\x12$\n\x0e\x61pplist_custom\x18\x05 \x03(\x0b\x32\x0c.ParentalApp\x12\x18\n\x10passwordhashtype\x18\x06 \x01(\r\x12\x0c\n\x04salt\x18\x07 \x01(\x0c\x12\x14\n\x0cpasswordhash\x18\x08 \x01(\x0c\x12\x12\n\nis_enabled\x18\t \x01(\x08\x12\x18\n\x10\x65nabled_features\x18\n \x01(\r\x12\x16\n\x0erecovery_email\x18\x0b \x01(\t\x12\x1c\n\x14is_site_license_lock\x18\x0c \x01(\x08\x12\"\n\x1atemporary_enabled_features\x18\r \x01(\r\x12*\n\"rtime_temporary_feature_expiration\x18\x0e \x01(\r\x12<\n\x15playtime_restrictions\x18\x0f \x01(\x0b\x32\x1d.ParentalPlaytimeRestrictions\x12O\n\x1ftemporary_playtime_restrictions\x18\x10 \x01(\x0b\x32&.ParentalTemporaryPlaytimeRestrictions\x12*\n\"excluded_store_content_descriptors\x18\x11 \x03(\r\x12.\n&excluded_community_content_descriptors\x18\x12 \x03(\r\x12\x16\n\x0eutility_appids\x18\x13 \x03(\r\"\xc3\x01\n\x16ParentalFeatureRequest\x12\x11\n\trequestid\x18\x01 \x01(\x06\x12\x16\n\x0e\x66\x61mily_groupid\x18\x02 \x01(\x06\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x10\n\x08\x66\x65\x61tures\x18\x04 \x01(\r\x12\x16\n\x0etime_requested\x18\x05 \x01(\r\x12\x10\n\x08\x61pproved\x18\x06 \x01(\x08\x12\x19\n\x11steamid_responder\x18\x07 \x01(\x06\x12\x16\n\x0etime_responded\x18\x08 \x01(\r\"\xcc\x02\n\x17ParentalPlaytimeRequest\x12\x11\n\trequestid\x18\x01 \x01(\x06\x12\x16\n\x0e\x66\x61mily_groupid\x18\x02 \x01(\x06\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12;\n\x1d\x63urrent_playtime_restrictions\x18\x04 \x01(\x0b\x32\x14.ParentalPlaytimeDay\x12\x14\n\x0ctime_expires\x18\x05 \x01(\r\x12\x16\n\x0etime_requested\x18\x06 \x01(\r\x12\x10\n\x08\x61pproved\x18\x07 \x01(\x08\x12\x19\n\x11steamid_responder\x18\x08 \x01(\x06\x12\x16\n\x0etime_responded\x18\t \x01(\r\x12\x45\n\x15restrictions_approved\x18\n \x01(\x0b\x32&.ParentalTemporaryPlaytimeRestrictionsB\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_parental_objects_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _PARENTALAPP._serialized_start=53
  _PARENTALAPP._serialized_end=101
  _PARENTALPLAYTIMEDAY._serialized_start=103
  _PARENTALPLAYTIMEDAY._serialized_end=185
  _PARENTALPLAYTIMERESTRICTIONS._serialized_start=187
  _PARENTALPLAYTIMERESTRICTIONS._serialized_end=299
  _PARENTALTEMPORARYPLAYTIMERESTRICTIONS._serialized_start=301
  _PARENTALTEMPORARYPLAYTIMERESTRICTIONS._serialized_end=407
  _PARENTALSETTINGS._serialized_start=410
  _PARENTALSETTINGS._serialized_end=1079
  _PARENTALFEATUREREQUEST._serialized_start=1082
  _PARENTALFEATUREREQUEST._serialized_end=1277
  _PARENTALPLAYTIMEREQUEST._serialized_start=1280
  _PARENTALPLAYTIMEREQUEST._serialized_end=1612
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x65nums.proto*\x80\n\n\x17\x45PublishedFileQueryType\x12)\n%k_PublishedFileQueryType_RankedByVote\x10\x00\x12\x34\n0k_PublishedFileQueryType_RankedByPublicationDate\x10\x01\x12\x42\n>k_PublishedFileQueryType_AcceptedForGameRankedByAcceptanceDate\x10\x02\x12*\n&k_PublishedFileQueryType_RankedByTrend\x10\x03\x12\x46\nBk_PublishedFileQueryType_FavoritedByFriendsRankedByPublicationDate\x10\x04\x12\x44\n@k_PublishedFileQueryType_CreatedByFriendsRankedByPublicationDate\x10\x05\x12\x35\n1k_PublishedFileQueryType_RankedByNumTimesReported\x10\x06\x12J\nFk_PublishedFileQueryType_CreatedByFollowedUsersRankedByPublicationDate\x10\x07\x12(\n$k_PublishedFileQueryType_NotYetRated\x10\x08\x12=\n9k_PublishedFileQueryType_RankedByTotalUniqueSubscriptions\x10\t\x12\x32\n.k_PublishedFileQueryType_RankedByTotalVotesAsc\x10\n\x12,\n(k_PublishedFileQueryType_RankedByVotesUp\x10\x0b\x12/\n+k_PublishedFileQueryType_RankedByTextSearch\x10\x0c\x12\x32\n.k_PublishedFileQueryType_RankedByPlaytimeTrend\x10\r\x12\x32\n.k_PublishedFileQueryType_RankedByTotalPlaytime\x10\x0e\x12\x39\n5k_PublishedFileQueryType_RankedByAveragePlaytimeTrend\x10\x0f\x12<\n8k_PublishedFileQueryType_RankedByLifetimeAveragePlaytime\x10\x10\x12:\n6k_PublishedFileQueryType_RankedByPlaytimeSessionsTrend\x10\x11\x12=\n9k_PublishedFileQueryType_RankedByLifetimePlaytimeSessions\x10\x12\x12?\n;k_PublishedFileQueryType_RankedByInappropriateContentRating\x10\x13\x12\x34\n0k_PublishedFileQueryType_RankedByBanContentCheck\x10\x14\x12\x34\n0k_PublishedFileQueryType_RankedByLastUpdatedDate\x10\x15*\xbc\x01\n#EPublishedFileInappropriateProvider\x12\x31\n-k_EPublishedFileInappropriateProvider_Invalid\x10\x00\x12\x30\n,k_EPublishedFileInappropriateProvider_Google\x10\x01\x12\x30\n,k_EPublishedFileInappropriateProvider_Amazon\x10\x02*\xd5\x02\n!EPublishedFileInappropriateResult\x12\x32\n.k_EPublishedFileInappropriateResult_NotScanned\x10\x00\x12\x34\n0k_EPublishedFileInappropriateResult_VeryUnlikely\x10\x01\x12\x30\n,k_EPublishedFileInappropriateResult_Unlikely\x10\x1e\x12\x30\n,k_EPublishedFileInappropriateResult_Possible\x10\x32\x12.\n*k_EPublishedFileInappropriateResult_Likely\x10K\x12\x32\n.k_EPublishedFileInappropriateResult_VeryLikely\x10\x64*\xb1\x03\n\x11\x45PersonaStateFlag\x12\'\n#k_EPersonaStateFlag_HasRichPresence\x10\x01\x12&\n\"k_EPersonaStateFlag_InJoinableGame\x10\x02\x12\x1e\n\x1ak_EPersonaStateFlag_Golden\x10\x04\x12*\n&k_EPersonaStateFlag_RemotePlayTogether\x10\x08\x12&\n!k_EPersonaStateFlag_ClientTypeWeb\x10\x80\x02\x12)\n$k_EPersonaStateFlag_ClientTypeMobile\x10\x80\x04\x12*\n%k_EPersonaStateFlag_ClientTypeTenfoot\x10\x80\x08\x12%\n k_EPersonaStateFlag_ClientTypeVR\x10\x80\x10\x12*\n%k_EPersonaStateFlag_LaunchTypeGamepad\x10\x80 \x12-\n(k_EPersonaStateFlag_LaunchTypeCompatTool\x10\x80@*\xb0\x02\n\x15\x45\x43ontentCheckProvider\x12#\n\x1fk_EContentCheckProvider_Invalid\x10\x00\x12-\n)k_EContentCheckProvider_Google_DEPRECATED\x10\x01\x12\"\n\x1ek_EContentCheckProvider_Amazon\x10\x02\x12!\n\x1dk_EContentCheckProvider_Local\x10\x03\x12*\n&k_EContentCheckProvider_GoogleVertexAI\x10\x04\x12(\n$k_EContentCheckProvider_GoogleGemini\x10\x05\x12&\n\"k_EContentCheckProvider_SteamLearn\x10\x06*\x93\t\n\x19\x45ProfileCustomizationType\x12&\n\"k_EProfileCustomizationTypeInvalid\x10\x00\x12\x36\n2k_EProfileCustomizationTypeRareAchievementShowcase\x10\x01\x12,\n(k_EProfileCustomizationTypeGameCollector\x10\x02\x12+\n\'k_EProfileCustomizationTypeItemShowcase\x10\x03\x12,\n(k_EProfileCustomizationTypeTradeShowcase\x10\x04\x12%\n!k_EProfileCustomizationTypeBadges\x10\x05\x12+\n\'k_EProfileCustomizationTypeFavoriteGame\x10\x06\x12\x31\n-k_EProfileCustomizationTypeScreenshotShowcase\x10\x07\x12)\n%k_EProfileCustomizationTypeCustomText\x10\x08\x12,\n(k_EProfileCustomizationTypeFavoriteGroup\x10\t\x12-\n)k_EProfileCustomizationTypeRecommendation\x10\n\x12+\n\'k_EProfileCustomizationTypeWorkshopItem\x10\x0b\x12)\n%k_EProfileCustomizationTypeMyWorkshop\x10\x0c\x12.\n*k_EProfileCustomizationTypeArtworkShowcase\x10\r\x12,\n(k_EProfileCustomizationTypeVideoShowcase\x10\x0e\x12%\n!k_EProfileCustomizationTypeGuides\x10\x0f\x12\'\n#k_EProfileCustomizationTypeMyGuides\x10\x10\x12+\n\'k_EProfileCustomizationTypeAchievements\x10\x11\x12)\n%k_EProfileCustomizationTypeGreenlight\x10\x12\x12+\n\'k_EProfileCustomizationTypeMyGreenlight\x10\x13\x12%\n!k_EProfileCustomizationTypeSalien\x10\x14\x12\x35\n1k_EProfileCustomizationTypeLoyaltyRewardReactions\x10\x15\x12\x34\n0k_EProfileCustomizationTypeSingleArtworkShowcase\x10\x16\x12\x38\n4k_EProfileCustomizationTypeAchievementsCompletionist\x10\x17\x12%\n!k_EProfileCustomizationTypeReplay\x10\x18*\xc8\x01\n\x1b\x45PublishedFileStorageSystem\x12(\n$k_EPublishedFileStorageSystemInvalid\x10\x00\x12,\n(k_EPublishedFileStorageSystemLegacyCloud\x10\x01\x12&\n\"k_EPublishedFileStorageSystemDepot\x10\x02\x12)\n%k_EPublishedFileStorageSystemUGCCloud\x10\x03*\x97\x01\n\x19\x45\x43loudStoragePersistState\x12(\n$k_ECloudStoragePersistStatePersisted\x10\x00\x12(\n$k_ECloudStoragePersistStateForgotten\x10\x01\x12&\n\"k_ECloudStoragePersistStateDeleted\x10\x02*\xe8\x01\n\x12\x45SDCardFormatStage\x12 \n\x1ck_ESDCardFormatStage_Invalid\x10\x00\x12!\n\x1dk_ESDCardFormatStage_Starting\x10\x01\x12 \n\x1ck_ESDCardFormatStage_Testing\x10\x02\x12!\n\x1dk_ESDCardFormatStage_Rescuing\x10\x03\x12#\n\x1fk_ESDCardFormatStage_Formatting\x10\x04\x12#\n\x1fk_ESDCardFormatStage_Finalizing\x10\x05*\x95\x02\n\x13\x45StorageFormatStage\x12!\n\x1dk_EStorageFormatStage_Invalid\x10\x00\x12$\n k_EStorageFormatStage_NotRunning\x10\x01\x12\"\n\x1ek_EStorageFormatStage_Starting\x10\x02\x12!\n\x1dk_EStorageFormatStage_Testing\x10\x03\x12\"\n\x1ek_EStorageFormatStage_Rescuing\x10\x04\x12$\n k_EStorageFormatStage_Formatting\x10\x05\x12$\n k_EStorageFormatStage_Finalizing\x10\x06*\x84\x01\n\x15\x45SystemFanControlMode\x12\"\n\x1ek_SystemFanControlMode_Invalid\x10\x00\x12#\n\x1fk_SystemFanControlMode_Disabled\x10\x01\x12\"\n\x1ek_SystemFanControlMode_Default\x10\x02*\xaa\x01\n\x14\x45StartupMovieVariant\x12\"\n\x1ek_EStartupMovieVariant_Invalid\x10\x00\x12\"\n\x1ek_EStartupMovieVariant_Generic\x10\x01\x12#\n\x1fk_EStartupMovieVariant_DeckBlue\x10\x02\x12%\n!k_EStartupMovieVariant_DeckOrange\x10\x03*\x8b\x01\n\x13\x45\x43olorGamutLabelSet\x12 \n\x1ck_ColorGamutLabelSet_Default\x10\x00\x12$\n k_ColorGamutLabelSet_sRGB_Native\x10\x01\x12,\n(k_ColorGamutLabelSet_Native_sRGB_Boosted\x10\x02*}\n\x14\x45WindowStackingOrder\x12\"\n\x1ek_EWindowStackingOrder_Invalid\x10\x00\x12\x1e\n\x1ak_EWindowStackingOrder_Top\x10\x01\x12!\n\x1dk_EWindowStackingOrder_Bottom\x10\x02*\xc0\x03\n\x14\x45\x42luetoothDeviceType\x12!\n\x1dk_BluetoothDeviceType_Invalid\x10\x00\x12!\n\x1dk_BluetoothDeviceType_Unknown\x10\x01\x12\x1f\n\x1bk_BluetoothDeviceType_Phone\x10\x02\x12\"\n\x1ek_BluetoothDeviceType_Computer\x10\x03\x12!\n\x1dk_BluetoothDeviceType_Headset\x10\x04\x12$\n k_BluetoothDeviceType_Headphones\x10\x05\x12\"\n\x1ek_BluetoothDeviceType_Speakers\x10\x06\x12$\n k_BluetoothDeviceType_OtherAudio\x10\x07\x12\x1f\n\x1bk_BluetoothDeviceType_Mouse\x10\x08\x12\"\n\x1ek_BluetoothDeviceType_Joystick\x10\t\x12!\n\x1dk_BluetoothDeviceType_Gamepad\x10\n\x12\"\n\x1ek_BluetoothDeviceType_Keyboard\x10\x0b*\x80\x01\n\x15\x45SystemAudioDirection\x12\"\n\x1ek_SystemAudioDirection_Invalid\x10\x00\x12 \n\x1ck_SystemAudioDirection_Input\x10\x01\x12!\n\x1dk_SystemAudioDirection_Output\x10\x02*\xf1\x02\n\x13\x45SystemAudioChannel\x12 \n\x1ck_SystemAudioChannel_Invalid\x10\x00\x12#\n\x1fk_SystemAudioChannel_Aggregated\x10\x01\x12\"\n\x1ek_SystemAudioChannel_FrontLeft\x10\x02\x12#\n\x1fk_SystemAudioChannel_FrontRight\x10\x03\x12\x1c\n\x18k_SystemAudioChannel_LFE\x10\x04\x12!\n\x1dk_SystemAudioChannel_BackLeft\x10\x05\x12\"\n\x1ek_SystemAudioChannel_BackRight\x10\x06\x12$\n k_SystemAudioChannel_FrontCenter\x10\x07\x12 \n\x1ck_SystemAudioChannel_Unknown\x10\x08\x12\x1d\n\x19k_SystemAudioChannel_Mono\x10\t*\xc9\x01\n\x14\x45SystemAudioPortType\x12!\n\x1dk_SystemAudioPortType_Invalid\x10\x00\x12!\n\x1dk_SystemAudioPortType_Unknown\x10\x01\x12\"\n\x1ek_SystemAudioPortType_Audio32f\x10\x02\x12 \n\x1ck_SystemAudioPortType_Midi8b\x10\x03\x12%\n!k_SystemAudioPortType_Video32RGBA\x10\x04*\x90\x01\n\x19\x45SystemAudioPortDirection\x12&\n\"k_SystemAudioPortDirection_Invalid\x10\x00\x12$\n k_SystemAudioPortDirection_Input\x10\x01\x12%\n!k_SystemAudioPortDirection_Output\x10\x02*\x83\x01\n\x13\x45SystemServiceState\x12%\n!k_ESystemServiceState_Unavailable\x10\x00\x12\"\n\x1ek_ESystemServiceState_Disabled\x10\x01\x12!\n\x1dk_ESystemServiceState_Enabled\x10\x02*\xe1\x01\n\x19\x45GraphicsPerfOverlayLevel\x12&\n\"k_EGraphicsPerfOverlayLevel_Hidden\x10\x00\x12%\n!k_EGraphicsPerfOverlayLevel_Basic\x10\x01\x12&\n\"k_EGraphicsPerfOverlayLevel_Medium\x10\x02\x12$\n k_EGraphicsPerfOverlayLevel_Full\x10\x03\x12\'\n#k_EGraphicsPerfOverlayLevel_Minimal\x10\x04*\xe5\x01\n\x14\x45GPUPerformanceLevel\x12\"\n\x1ek_EGPUPerformanceLevel_Invalid\x10\x00\x12\x1f\n\x1bk_EGPUPerformanceLevel_Auto\x10\x01\x12!\n\x1dk_EGPUPerformanceLevel_Manual\x10\x02\x12\x1e\n\x1ak_EGPUPerformanceLevel_Low\x10\x03\x12\x1f\n\x1bk_EGPUPerformanceLevel_High\x10\x04\x12$\n k_EGPUPerformanceLevel_Profiling\x10\x05*\xc8\x01\n\x13\x45SplitScalingFilter\x12!\n\x1dk_ESplitScalingFilter_Invalid\x10\x00\x12 \n\x1ck_ESplitScalingFilter_Linear\x10\x01\x12!\n\x1dk_ESplitScalingFilter_Nearest\x10\x02\x12\x1f\n\x1bk_ESplitScalingFilter_Sharp\x10\x03\x12(\n$k_ESplitScalingFilter_NIS_Deprecated\x10\x04*\xdd\x01\n\x13\x45SplitScalingScaler\x12!\n\x1dk_ESplitScalingScaler_Invalid\x10\x00\x12\x1e\n\x1ak_ESplitScalingScaler_Auto\x10\x01\x12!\n\x1dk_ESplitScalingScaler_Integer\x10\x02\x12\x1d\n\x19k_ESplitScalingScaler_Fit\x10\x03\x12\x1e\n\x1ak_ESplitScalingScaler_Fill\x10\x04\x12!\n\x1dk_ESplitScalingScaler_Stretch\x10\x05*}\n\x12\x45GamescopeBlurMode\x12!\n\x1dk_EGamescopeBlurMode_Disabled\x10\x00\x12#\n\x1fk_EGamescopeBlurMode_IfOccluded\x10\x01\x12\x1f\n\x1bk_EGamescopeBlurMode_Always\x10\x02*\xc4\x01\n\nESLSHelper\x12\x18\n\x14k_ESLSHelper_Invalid\x10\x00\x12\x19\n\x15k_ESLSHelper_Minidump\x10\x01\x12\x16\n\x12k_ESLSHelper_Kdump\x10\x02\x12\x18\n\x14k_ESLSHelper_Journal\x10\x03\x12\x14\n\x10k_ESLSHelper_Gpu\x10\x04\x12\x1b\n\x17k_ESLSHelper_SystemInfo\x10\x05\x12\x1c\n\x18k_ESLSHelper_Devcoredump\x10\x06*\xc5\x01\n\x11\x45HDRVisualization\x12\x1c\n\x18k_EHDRVisualization_None\x10\x00\x12\x1f\n\x1bk_EHDRVisualization_Heatmap\x10\x01\x12 \n\x1ck_EHDRVisualization_Analysis\x10\x02\x12\'\n#k_EHDRVisualization_HeatmapExtended\x10\x03\x12&\n\"k_EHDRVisualization_HeatmapClassic\x10\x04*\x81\x01\n\x13\x45HDRToneMapOperator\x12!\n\x1dk_EHDRToneMapOperator_Invalid\x10\x00\x12#\n\x1fk_EHDRToneMapOperator_Uncharted\x10\x01\x12\"\n\x1ek_EHDRToneMapOperator_Reinhard\x10\x02*|\n\x0c\x45\x43PUGovernor\x12\x1a\n\x16k_ECPUGovernor_Invalid\x10\x00\x12\x17\n\x13k_ECPUGovernor_Perf\x10\x01\x12\x1c\n\x18k_ECPUGovernor_Powersave\x10\x02\x12\x19\n\x15k_ECPUGovernor_Manual\x10\x03*\xe2\x01\n\x0c\x45UpdaterType\x12\x1a\n\x16k_EUpdaterType_Invalid\x10\x00\x12\x19\n\x15k_EUpdaterType_Client\x10\x01\x12\x15\n\x11k_EUpdaterType_OS\x10\x02\x12\x17\n\x13k_EUpdaterType_BIOS\x10\x03\x12\x1d\n\x19k_EUpdaterType_Aggregated\x10\x04\x12\x18\n\x14k_EUpdaterType_Test1\x10\x05\x12\x18\n\x14k_EUpdaterType_Test2\x10\x06\x12\x18\n\x14k_EUpdaterType_Dummy\x10\x07*\x97\x02\n\rEUpdaterState\x12\x1b\n\x17k_EUpdaterState_Invalid\x10\x00\x12\x1c\n\x18k_EUpdaterState_UpToDate\x10\x02\x12\x1c\n\x18k_EUpdaterState_Checking\x10\x03\x12\x1d\n\x19k_EUpdaterState_Available\x10\x04\x12\x1c\n\x18k_EUpdaterState_Applying\x10\x05\x12(\n$k_EUpdaterState_ClientRestartPending\x10\x06\x12(\n$k_EUpdaterState_SystemRestartPending\x10\x07\x12\x1c\n\x18k_EUpdaterState_RollBack\x10\x08*\xe1\x01\n\x18\x45StorageBlockContentType\x12&\n\"k_EStorageBlockContentType_Invalid\x10\x00\x12&\n\"k_EStorageBlockContentType_Unknown\x10\x01\x12)\n%k_EStorageBlockContentType_FileSystem\x10\x02\x12%\n!k_EStorageBlockContentType_Crypto\x10\x03\x12#\n\x1fk_EStorageBlockContentType_Raid\x10\x04*\xc3\x01\n\x1b\x45StorageBlockFileSystemType\x12)\n%k_EStorageBlockFileSystemType_Invalid\x10\x00\x12)\n%k_EStorageBlockFileSystemType_Unknown\x10\x01\x12&\n\"k_EStorageBlockFileSystemType_VFat\x10\x02\x12&\n\"k_EStorageBlockFileSystemType_Ext4\x10\x03*\xd0\x01\n\x16\x45StorageDriveMediaType\x12$\n k_EStorageDriveMediaType_Invalid\x10\x00\x12$\n k_EStorageDriveMediaType_Unknown\x10\x01\x12 \n\x1ck_EStorageDriveMediaType_HDD\x10\x02\x12 \n\x1ck_EStorageDriveMediaType_SSD\x10\x03\x12&\n\"k_EStorageDriveMediaType_Removable\x10\x04*\xb3\x01\n\x1f\x45SystemDisplayCompatibilityMode\x12-\n)k_ESystemDisplayCompatibilityMode_Invalid\x10\x00\x12*\n&k_ESystemDisplayCompatibilityMode_None\x10\x01\x12\x35\n1k_ESystemDisplayCompatibilityMode_MinimalBandwith\x10\x02*\xad\x01\n\x1d\x45SteamOSCompatibilityCategory\x12+\n\'k_ESteamOSCompatibilityCategory_Unknown\x10\x00\x12/\n+k_ESteamOSCompatibilityCategory_Unsupported\x10\x01\x12.\n*k_ESteamOSCompatibilityCategory_Compatible\x10\x02*\x8f\x02\n&ESteamOSCompatibilityResultDisplayType\x12\x36\n2k_ESteamOSCompatibilityResultDisplayType_Invisible\x10\x00\x12:\n6k_ESteamOSCompatibilityResultDisplayType_Informational\x10\x01\x12\x38\n4k_ESteamOSCompatibilityResultDisplayType_Unsupported\x10\x02\x12\x37\n3k_ESteamOSCompatibilityResultDisplayType_Compatible\x10\x03*\xe3\x01\n\x1f\x45SteamDeckCompatibilityCategory\x12-\n)k_ESteamDeckCompatibilityCategory_Unknown\x10\x00\x12\x31\n-k_ESteamDeckCompatibilityCategory_Unsupported\x10\x01\x12.\n*k_ESteamDeckCompatibilityCategory_Playable\x10\x02\x12.\n*k_ESteamDeckCompatibilityCategory_Verified\x10\x03*\xd0\x02\n(ESteamDeckCompatibilityResultDisplayType\x12\x38\n4k_ESteamDeckCompatibilityResultDisplayType_Invisible\x10\x00\x12<\n8k_ESteamDeckCompatibilityResultDisplayType_Informational\x10\x01\x12:\n6k_ESteamDeckCompatibilityResultDisplayType_Unsupported\x10\x02\x12\x37\n3k_ESteamDeckCompatibilityResultDisplayType_Playable\x10\x03\x12\x37\n3k_ESteamDeckCompatibilityResultDisplayType_Verified\x10\x04*\x9a\x02\n!ESteamDeckCompatibilityTestResult\x12/\n+k_ESteamDeckCompatibilityTestResult_Invalid\x10\x00\x12\x35\n1k_ESteamDeckCompatibilityTestResult_NotApplicable\x10\x01\x12,\n(k_ESteamDeckCompatibilityTestResult_Pass\x10\x02\x12,\n(k_ESteamDeckCompatibilityTestResult_Fail\x10\x03\x12\x31\n-k_ESteamDeckCompatibilityTestResult_FailMinor\x10\x04*w\n\x08\x45\x41\x43State\x12\x16\n\x12k_EACState_Unknown\x10\x00\x12\x1b\n\x17k_EACState_Disconnected\x10\x01\x12\x18\n\x14k_EACState_Connected\x10\x02\x12\x1c\n\x18k_EACState_ConnectedSlow\x10\x03*\x85\x01\n\rEBatteryState\x12\x1b\n\x17k_EBatteryState_Unknown\x10\x00\x12\x1f\n\x1bk_EBatteryState_Discharging\x10\x01\x12\x1c\n\x18k_EBatteryState_Charging\x10\x02\x12\x18\n\x14k_EBatteryState_Full\x10\x03*\xfe\x01\n\tEOSBranch\x12\x17\n\x13k_EOSBranch_Unknown\x10\x00\x12\x17\n\x13k_EOSBranch_Release\x10\x01\x12 \n\x1ck_EOSBranch_ReleaseCandidate\x10\x02\x12\x14\n\x10k_EOSBranch_Beta\x10\x03\x12\x1d\n\x19k_EOSBranch_BetaCandidate\x10\x04\x12\x17\n\x13k_EOSBranch_Preview\x10\x05\x12 \n\x1ck_EOSBranch_PreviewCandidate\x10\x06\x12\x14\n\x10k_EOSBranch_Main\x10\x07\x12\x17\n\x13k_EOSBranch_Staging\x10\x08*\xc6\x03\n\x11\x45\x42rowserGPUStatus\x12\x1f\n\x1bk_EBrowserGPUStatus_Invalid\x10\x00\x12\x1f\n\x1bk_EBrowserGPUStatus_Enabled\x10\x01\x12\'\n#k_EBrowserGPUStatus_DisabledUnknown\x10\x02\x12*\n&k_EBrowserGPUStatus_DisabledCrashCount\x10\x04\x12)\n%k_EBrowserGPUStatus_DisabledBlocklist\x10\x05\x12)\n%k_EBrowserGPUStatus_DisabledJSRequest\x10\x06\x12+\n\'k_EBrowserGPUStatus_DisabledCommandLine\x10\x07\x12-\n)k_EBrowserGPUStatus_DisabledRuntimeDetect\x10\x08\x12\x30\n,k_EBrowserGPUStatus_DisabledChildCommandLine\x10\t\x12\x36\n2k_EBrowserGPUStatus_DisabledCompositingCommandLine\x10\n*\xe3\x04\n\x15\x45\x42rowserFeatureStatus\x12#\n\x1fk_EBrowserFeatureStatus_Invalid\x10\x00\x12$\n k_EBrowserFeatureStatus_NotFound\x10\x01\x12#\n\x1fk_EBrowserFeatureStatus_Unknown\x10\x02\x12,\n(k_EBrowserFeatureStatus_DisabledSoftware\x10\x03\x12\'\n#k_EBrowserFeatureStatus_DisabledOff\x10\x04\x12)\n%k_EBrowserFeatureStatus_DisabledOffOk\x10\x05\x12/\n+k_EBrowserFeatureStatus_UnavailableSoftware\x10\x06\x12*\n&k_EBrowserFeatureStatus_UnavailableOff\x10\x07\x12,\n(k_EBrowserFeatureStatus_UnavailableOffOk\x10\x08\x12+\n\'k_EBrowserFeatureStatus_EnabledReadback\x10\t\x12(\n$k_EBrowserFeatureStatus_EnabledForce\x10\n\x12#\n\x1fk_EBrowserFeatureStatus_Enabled\x10\x0b\x12%\n!k_EBrowserFeatureStatus_EnabledOn\x10\x0c\x12*\n&k_EBrowserFeatureStatus_EnabledForceOn\x10\r*\x9f\x05\n\x0c\x45GpuDriverId\x12\x1a\n\x16k_EGpuDriverId_Invalid\x10\x00\x12\x1a\n\x16k_EGpuDriverId_Unknown\x10\x01\x12!\n\x1dk_EGpuDriverId_AmdProprietary\x10\x02\x12 \n\x1ck_EGpuDriverId_AmdOpenSource\x10\x03\x12\x1b\n\x17k_EGpuDriverId_MesaRadv\x10\x04\x12$\n k_EGpuDriverId_NvidiaProprietary\x10\x05\x12\"\n\x1ek_EGpuDriverId_IntelPropietary\x10\x06\x12\x1c\n\x18k_EGpuDriverId_MesaIntel\x10\x07\x12&\n\"k_EGpuDriverId_QualcommProprietary\x10\x08\x12!\n\x1dk_EGpuDriverId_ArmProprietary\x10\t\x12$\n k_EGpuDriverId_GoogleSwiftshader\x10\n\x12&\n\"k_EGpuDriverId_BroadcomProprietary\x10\x0b\x12\x1f\n\x1bk_EGpuDriverId_MesaLLVMPipe\x10\x0c\x12\x1b\n\x17k_EGpuDriverId_MoltenVK\x10\r\x12\x1d\n\x19k_EGpuDriverId_MesaTurnip\x10\x0e\x12\x1c\n\x18k_EGpuDriverId_MesaPanVK\x10\x0f\x12\x1c\n\x18k_EGpuDriverId_MesaVenus\x10\x10\x12\x1c\n\x18k_EGpuDriverId_MesaDozen\x10\x11\x12\x1a\n\x16k_EGpuDriverId_MesaNVK\x10\x12\x12!\n\x1dk_EGpuDriverId_MesaHoneyKrisp\x10\x13*\xdd\x05\n\x13\x45\x43ommunityItemClass\x12!\n\x1dk_ECommunityItemClass_Invalid\x10\x00\x12\x1f\n\x1bk_ECommunityItemClass_Badge\x10\x01\x12\"\n\x1ek_ECommunityItemClass_GameCard\x10\x02\x12+\n\'k_ECommunityItemClass_ProfileBackground\x10\x03\x12\"\n\x1ek_ECommunityItemClass_Emoticon\x10\x04\x12%\n!k_ECommunityItemClass_BoosterPack\x10\x05\x12$\n k_ECommunityItemClass_Consumable\x10\x06\x12!\n\x1dk_ECommunityItemClass_GameGoo\x10\x07\x12)\n%k_ECommunityItemClass_ProfileModifier\x10\x08\x12\x1f\n\x1bk_ECommunityItemClass_Scene\x10\t\x12$\n k_ECommunityItemClass_SalienItem\x10\n\x12!\n\x1dk_ECommunityItemClass_Sticker\x10\x0b\x12$\n k_ECommunityItemClass_ChatEffect\x10\x0c\x12/\n+k_ECommunityItemClass_MiniProfileBackground\x10\r\x12%\n!k_ECommunityItemClass_AvatarFrame\x10\x0e\x12(\n$k_ECommunityItemClass_AnimatedAvatar\x10\x0f\x12/\n+k_ECommunityItemClass_SteamDeckKeyboardSkin\x10\x10\x12/\n+k_ECommunityItemClass_SteamDeckStartupMovie\x10\x11*\xd9\x01\n\x1f\x45SteamDeckCompatibilityFeedback\x12+\n\'k_ESteamDeckCompatibilityFeedback_Unset\x10\x00\x12+\n\'k_ESteamDeckCompatibilityFeedback_Agree\x10\x01\x12.\n*k_ESteamDeckCompatibilityFeedback_Disagree\x10\x02\x12,\n(k_ESteamDeckCompatibilityFeedback_Ignore\x10\x03*\x9f\x01\n\x1e\x45ProvideDeckFeedbackPreference\x12*\n&k_EProvideDeckFeedbackPreference_Unset\x10\x00\x12(\n$k_EProvideDeckFeedbackPreference_Yes\x10\x01\x12\'\n#k_EProvideDeckFeedbackPreference_No\x10\x02*\xb1\x03\n\rETouchGesture\x12\x17\n\x13k_ETouchGestureNone\x10\x00\x12\x18\n\x14k_ETouchGestureTouch\x10\x01\x12\x16\n\x12k_ETouchGestureTap\x10\x02\x12\x1c\n\x18k_ETouchGestureDoubleTap\x10\x03\x12\x1d\n\x19k_ETouchGestureShortPress\x10\x04\x12\x1c\n\x18k_ETouchGestureLongPress\x10\x05\x12\x1a\n\x16k_ETouchGestureLongTap\x10\x06\x12\x1f\n\x1bk_ETouchGestureTwoFingerTap\x10\x07\x12\x1f\n\x1bk_ETouchGestureTapCancelled\x10\x08\x12\x1d\n\x19k_ETouchGesturePinchBegin\x10\t\x12\x1e\n\x1ak_ETouchGesturePinchUpdate\x10\n\x12\x1b\n\x17k_ETouchGesturePinchEnd\x10\x0b\x12\x1d\n\x19k_ETouchGestureFlingStart\x10\x0c\x12!\n\x1dk_ETouchGestureFlingCancelled\x10\r*\x8c\x01\n\x13\x45SessionPersistence\x12*\n\x1dk_ESessionPersistence_Invalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12#\n\x1fk_ESessionPersistence_Ephemeral\x10\x00\x12$\n k_ESessionPersistence_Persistent\x10\x01*\xd9\x01\n\x1a\x45NewSteamAnnouncementState\x12(\n$k_ENewSteamAnnouncementState_Invalid\x10\x00\x12(\n$k_ENewSteamAnnouncementState_AllRead\x10\x01\x12\x30\n,k_ENewSteamAnnouncementState_NewAnnouncement\x10\x02\x12\x35\n1k_ENewSteamAnnouncementState_FeaturedAnnouncement\x10\x03*\xfe\x01\n\nEForumType\x12\x18\n\x14k_EForumType_Invalid\x10\x00\x12\x18\n\x14k_EForumType_General\x10\x01\x12\x1e\n\x1ak_EForumType_ReportedPosts\x10\x02\x12\x19\n\x15k_EForumType_Workshop\x10\x03\x12\x1e\n\x1ak_EForumType_PublishedFile\x10\x04\x12\x18\n\x14k_EForumType_Trading\x10\x05\x12\x19\n\x15k_EForumType_PlayTest\x10\x06\x12\x16\n\x12k_EForumType_Event\x10\x07\x12\x14\n\x10k_EForumType_Max\x10\x08*\x8b\x07\n\x12\x45\x43ommentThreadType\x12\x1f\n\x1bk_ECommentThreadTypeInvalid\x10\x00\x12-\n)k_ECommentThreadTypeScreenshot_Deprecated\x10\x01\x12\x31\n-k_ECommentThreadTypeWorkshopAccount_Developer\x10\x02\x12.\n*k_ECommentThreadTypeWorkshopAccount_Public\x10\x03\x12/\n+k_ECommentThreadTypePublishedFile_Developer\x10\x04\x12,\n(k_ECommentThreadTypePublishedFile_Public\x10\x05\x12\x1c\n\x18k_ECommentThreadTypeTest\x10\x06\x12\"\n\x1ek_ECommentThreadTypeForumTopic\x10\x07\x12&\n\"k_ECommentThreadTypeRecommendation\x10\x08\x12(\n$k_ECommentThreadTypeVideo_Deprecated\x10\t\x12\x1f\n\x1bk_ECommentThreadTypeProfile\x10\n\x12 \n\x1ck_ECommentThreadTypeNewsPost\x10\x0b\x12\x1c\n\x18k_ECommentThreadTypeClan\x10\x0c\x12(\n$k_ECommentThreadTypeClanAnnouncement\x10\r\x12!\n\x1dk_ECommentThreadTypeClanEvent\x10\x0e\x12+\n\'k_ECommentThreadTypeUserStatusPublished\x10\x0f\x12+\n\'k_ECommentThreadTypeUserReceivedNewGame\x10\x10\x12\x32\n.k_ECommentThreadTypePublishedFile_Announcement\x10\x11\x12(\n$k_ECommentThreadTypeModeratorMessage\x10\x12\x12&\n\"k_ECommentThreadTypeClanCuratedApp\x10\x13\x12$\n k_ECommentThreadTypeQAndASession\x10\x14\x12\x1b\n\x17k_ECommentThreadTypeMax\x10\x15*\xd7\x01\n\x14\x45\x42roadcastPermission\x12\"\n\x1ek_EBroadcastPermissionDisabled\x10\x00\x12(\n$k_EBroadcastPermissionFriendsApprove\x10\x01\x12(\n$k_EBroadcastPermissionFriendsAllowed\x10\x02\x12 \n\x1ck_EBroadcastPermissionPublic\x10\x03\x12%\n!k_EBroadcastPermissionSubscribers\x10\x04*f\n\x18\x45\x42roadcastEncoderSetting\x12\"\n\x1ek_EBroadcastEncoderBestQuality\x10\x00\x12&\n\"k_EBroadcastEncoderBestPerformance\x10\x01*y\n\x14\x45\x43loudGamingPlatform\x12\x1e\n\x1ak_ECloudGamingPlatformNone\x10\x00\x12\x1f\n\x1bk_ECloudGamingPlatformValve\x10\x01\x12 \n\x1ck_ECloudGamingPlatformNVIDIA\x10\x02*\xed\x02\n\x18\x45\x43ompromiseDetectionType\x12#\n\x1fk_ECompromiseDetectionType_None\x10\x00\x12)\n%k_ECompromiseDetectionType_TradeEvent\x10\x01\x12*\n&k_ECompromiseDetectionType_ApiCallRate\x10\x02\x12%\n!k_ECompromiseDetectionType_Manual\x10\x03\x12+\n\'k_ECompromiseDetectionType_TicketAction\x10\x04\x12.\n*k_ECompromiseDetectionType_MaliciousRefund\x10\x05\x12&\n\"k_ECompromiseDetectionType_Move2FA\x10\x06\x12)\n%k_ECompromiseDetectionType_DeviceType\x10\x07*\xd6\x01\n\x1a\x45\x41syncGameSessionUserState\x12\x30\n#k_EAsyncGameSessionUserStateUnknown\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n,k_EAsyncGameSessionUserStateWaitingForOthers\x10\x00\x12.\n*k_EAsyncGameSessionUserStateReadyForAction\x10\x01\x12$\n k_EAsyncGameSessionUserStateDone\x10\x02*\xc4\x01\n\x1f\x45\x41syncGameSessionUserVisibility\x12;\n7k_EAsyncGameSessionUserVisibilityEnvelopeAndSessionList\x10\x00\x12\x34\n0k_EAsyncGameSessionUserVisibilitySessionListOnly\x10\x01\x12.\n*k_EAsyncGameSessionUserVisibilityDismissed\x10\x02*\xd4\x01\n\x12\x45GameRecordingType\x12 \n\x1ck_EGameRecordingType_Unknown\x10\x00\x12%\n!k_EGameRecordingType_NotRecording\x10\x01\x12(\n$k_EGameRecordingType_ManualRecording\x10\x02\x12,\n(k_EGameRecordingType_BackgroundRecording\x10\x03\x12\x1d\n\x19k_EGameRecordingType_Clip\x10\x04*\\\n\x0c\x45\x45xportCodec\x12\x1a\n\x16k_EExportCodec_Default\x10\x00\x12\x17\n\x13k_EExportCodec_H264\x10\x01\x12\x17\n\x13k_EExportCodec_H265\x10\x02*\xea\x03\n\rEProtoAppType\x12\x15\n\x11k_EAppTypeInvalid\x10\x00\x12\x12\n\x0ek_EAppTypeGame\x10\x01\x12\x19\n\x15k_EAppTypeApplication\x10\x02\x12\x12\n\x0ek_EAppTypeTool\x10\x04\x12\x12\n\x0ek_EAppTypeDemo\x10\x08\x12\x17\n\x13k_EAppTypeDeprected\x10\x10\x12\x11\n\rk_EAppTypeDLC\x10 \x12\x13\n\x0fk_EAppTypeGuide\x10@\x12\x15\n\x10k_EAppTypeDriver\x10\x80\x01\x12\x15\n\x10k_EAppTypeConfig\x10\x80\x02\x12\x17\n\x12k_EAppTypeHardware\x10\x80\x04\x12\x18\n\x13k_EAppTypeFranchise\x10\x80\x08\x12\x14\n\x0fk_EAppTypeVideo\x10\x80\x10\x12\x15\n\x10k_EAppTypePlugin\x10\x80 \x12\x19\n\x14k_EAppTypeMusicAlbum\x10\x80@\x12\x16\n\x10k_EAppTypeSeries\x10\x80\x80\x01\x12\x15\n\x0fk_EAppTypeComic\x10\x80\x80\x02\x12\x14\n\x0ek_EAppTypeBeta\x10\x80\x80\x04\x12\x1a\n\x12k_EAppTypeShortcut\x10\x80\x80\x80\x80\x04\x12 \n\x13k_EAppTypeDepotOnly\x10\x80\x80\x80\x80\xf8\xff\xff\xff\xff\x01*\x96\x01\n\x19\x45\x43hildProcessQueryCommand\x12\'\n#k_EChildProcessQueryCommand_Invalid\x10\x00\x12+\n\'k_EChildProcessQueryCommand_GpuTopology\x10\x01\x12#\n\x1fk_EChildProcessQueryCommand_Max\x10\x02*\xf6\x02\n\x1a\x45\x43hildProcessQueryExitCode\x12(\n$k_EChildProcessQueryExitCode_Success\x10\x00\x12:\n-k_EChildProcessQueryExitCode_ErrorCommandline\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'k_EChildProcessQueryExitCode_ErrorOther\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/k_EChildProcessQueryExitCode_ErrorUnimplemented\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*k_EChildProcessQueryExitCode_ErrorFileSave\x10\xfc\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x45\n8k_EChildProcessQueryExitCode_ErrorNotSupportedByPlatform\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xf2\x01\n EWindowsUpdateInstallationImpact\x12\x37\n*k_EWindowsUpdateInstallationImpact_Unknown\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n)k_EWindowsUpdateInstallationImpact_Normal\x10\x00\x12,\n(k_EWindowsUpdateInstallationImpact_Minor\x10\x01\x12\x38\n4k_EWindowsUpdateInstallationImpact_ExclusiveHandling\x10\x02*\xf2\x01\n\x1c\x45WindowsUpdateRebootBehavior\x12\x33\n&k_EWindowsUpdateRebootBehavior_Unknown\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n/k_EWindowsUpdateRebootBehavior_NeverNeedsReboot\x10\x00\x12\x34\n0k_EWindowsUpdateRebootBehavior_AlwaysNeedsReboot\x10\x01\x12\x32\n.k_EWindowsUpdateRebootBehavior_MightNeedReboot\x10\x02*\xfe\x01\n\x16\x45\x45xternalSaleEventType\x12$\n k_EExternalSaleEventType_Unknown\x10\x00\x12&\n\"k_EExternalSaleEventType_Publisher\x10\x01\x12%\n!k_EExternalSaleEventType_Showcase\x10\x02\x12#\n\x1fk_EExternalSaleEventType_Region\x10\x03\x12\"\n\x1ek_EExternalSaleEventType_Theme\x10\x04\x12&\n\"k_EExternalSaleEventType_Franchise\x10\x05*\xe9\x01\n\x19\x45\x43ontentReportSubjectType\x12\'\n#k_EContentReportSubjectType_Invalid\x10\x00\x12)\n%k_EContentReportSubjectType_ForumPost\x10\x01\x12*\n&k_EContentReportSubjectType_UGCComment\x10\x02\x12\'\n#k_EContentReportSubjectType_UGCFile\x10\x03\x12#\n\x1fk_EContentReportSubjectType_MAX\x10\x04*\xda\x02\n\x14\x45\x43ontentReportReason\x12\"\n\x1ek_EContentReportReason_Invalid\x10\x00\x12\"\n\x1ek_EContentReportReason_Abusive\x10\x01\x12%\n!k_EContentReportReason_Commercial\x10\x02\x12#\n\x1fk_EContentReportReason_OffTopic\x10\x03\x12%\n!k_EContentReportReason_Prohibited\x10\x04\x12 \n\x1ck_EContentReportReason_Other\x10\x05\x12\x1f\n\x1bk_EContentReportReason_CSAM\x10\x06\x12$\n k_EContentReportReason_Terrorism\x10\x07\x12\x1e\n\x1ak_EContentReportReason_MAX\x10\x08*\xd9\x01\n\x1e\x45\x43ontrolledLegalCategoryStatus\x12)\n%k_EControlledLegalCategoryStatus_None\x10\x00\x12,\n(k_EControlledLegalCategoryStatus_Accused\x10\x01\x12.\n*k_EControlledLegalCategoryStatus_Convicted\x10\x02\x12.\n*k_EControlledLegalCategoryStatus_Acquitted\x10\x03*\xa9\x01\n\x16\x45\x43ontentModeratorLevel\x12 \n\x1ck_EContentModeratorLevel_Any\x10\x00\x12\'\n#k_EContentModeratorLevel_Supervisor\x10\x01\x12\"\n\x1ek_EContentModeratorLevel_Valve\x10\n\x12 \n\x1ck_EContentModeratorLevel_MAX\x10\x0b*\xe6\x01\n\x18\x45\x43ontentReportResolution\x12)\n%k_EContentReportResolution_Unresolved\x10\x00\x12(\n$k_EContentReportResolution_Acquitted\x10\x01\x12&\n\"k_EContentReportResolution_Removed\x10\x02\x12)\n%k_EContentReportResolution_Relabelled\x10\x03\x12\"\n\x1ek_EContentReportResolution_MAX\x10\x04*\xd8\x01\n\x17\x45\x43ontentModeratedReason\x12%\n!k_EContentModeratedReason_Invalid\x10\x00\x12\"\n\x1ek_EContentModeratedReason_None\x10\x01\x12%\n!k_EContentModeratedReason_Unknown\x10\x02\x12(\n$k_EContentModeratedReason_AnimalHarm\x10\x03\x12!\n\x1dk_EContentModeratedReason_MAX\x10\x04\x42\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enums_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _EPUBLISHEDFILEQUERYTYPE._serialized_start=16
  _EPUBLISHEDFILEQUERYTYPE._serialized_end=1296
  _EPUBLISHEDFILEINAPPROPRIATEPROVIDER._serialized_start=1299
  _EPUBLISHEDFILEINAPPROPRIATEPROVIDER._serialized_end=1487
  _EPUBLISHEDFILEINAPPROPRIATERESULT._serialized_start=1490
  _EPUBLISHEDFILEINAPPROPRIATERESULT._serialized_end=1831
  _EPERSONASTATEFLAG._serialized_start=1834
  _EPERSONASTATEFLAG._serialized_end=2267
  _ECONTENTCHECKPROVIDER._serialized_start=2270
  _ECONTENTCHECKPROVIDER._serialized_end=2574
  _EPROFILECUSTOMIZATIONTYPE._serialized_start=2577
  _EPROFILECUSTOMIZATIONTYPE._serialized_end=3748
  _EPUBLISHEDFILESTORAGESYSTEM._serialized_start=3751
  _EPUBLISHEDFILESTORAGESYSTEM._serialized_end=3951
  _ECLOUDSTORAGEPERSISTSTATE._serialized_start=3954
  _ECLOUDSTORAGEPERSISTSTATE._serialized_end=4105
  _ESDCARDFORMATSTAGE._serialized_start=4108
  _ESDCARDFORMATSTAGE._serialized_end=4340
  _ESTORAGEFORMATSTAGE._serialized_start=4343
  _ESTORAGEFORMATSTAGE._serialized_end=4620
  _ESYSTEMFANCONTROLMODE._serialized_start=4623
  _ESYSTEMFANCONTROLMODE._serialized_end=4755
  _ESTARTUPMOVIEVARIANT._serialized_start=4758
  _ESTARTUPMOVIEVARIANT._serialized_end=4928
  _ECOLORGAMUTLABELSET._serialized_start=4931
  _ECOLORGAMUTLABELSET._serialized_end=5070
  _EWINDOWSTACKINGORDER._serialized_start=5072
  _EWINDOWSTACKINGORDER._serialized_end=5197
  _EBLUETOOTHDEVICETYPE._serialized_start=5200
  _EBLUETOOTHDEVICETYPE._serialized_end=5648
  _ESYSTEMAUDIODIRECTION._serialized_start=5651
  _ESYSTEMAUDIODIRECTION._serialized_end=5779
  _ESYSTEMAUDIOCHANNEL._serialized_start=5782
  _ESYSTEMAUDIOCHANNEL._serialized_end=6151
  _ESYSTEMAUDIOPORTTYPE._serialized_start=6154
  _ESYSTEMAUDIOPORTTYPE._serialized_end=6355
  _ESYSTEMAUDIOPORTDIRECTION._serialized_start=6358
  _ESYSTEMAUDIOPORTDIRECTION._serialized_end=6502
  _ESYSTEMSERVICESTATE._serialized_start=6505
  _ESYSTEMSERVICESTATE._serialized_end=6636
  _EGRAPHICSPERFOVERLAYLEVEL._serialized_start=6639
  _EGRAPHICSPERFOVERLAYLEVEL._serialized_end=6864
  _EGPUPERFORMANCELEVEL._serialized_start=6867
  _EGPUPERFORMANCELEVEL._serialized_end=7096
  _ESPLITSCALINGFILTER._serialized_start=7099
  _ESPLITSCALINGFILTER._serialized_end=7299
  _ESPLITSCALINGSCALER._serialized_start=7302
  _ESPLITSCALINGSCALER._serialized_end=7523
  _EGAMESCOPEBLURMODE._serialized_start=7525
  _EGAMESCOPEBLURMODE._serialized_end=7650
  _ESLSHELPER._serialized_start=7653
  _ESLSHELPER._serialized_end=7849
  _EHDRVISUALIZATION._serialized_start=7852
  _EHDRVISUALIZATION._serialized_end=8049
  _EHDRTONEMAPOPERATOR._serialized_start=8052
  _EHDRTONEMAPOPERATOR._serialized_end=8181
  _ECPUGOVERNOR._serialized_start=8183
  _ECPUGOVERNOR._serialized_end=8307
  _EUPDATERTYPE._serialized_start=8310
  _EUPDATERTYPE._serialized_end=8536
  _EUPDATERSTATE._serialized_start=8539
  _EUPDATERSTATE._serialized_end=8818
  _ESTORAGEBLOCKCONTENTTYPE._serialized_start=8821
  _ESTORAGEBLOCKCONTENTTYPE._serialized_end=9046
  _ESTORAGEBLOCKFILESYSTEMTYPE._serialized_start=9049
  _ESTORAGEBLOCKFILESYSTEMTYPE._serialized_end=9244
  _ESTORAGEDRIVEMEDIATYPE._serialized_start=9247
  _ESTORAGEDRIVEMEDIATYPE._serialized_end=9455
  _ESYSTEMDISPLAYCOMPATIBILITYMODE._serialized_start=9458
  _ESYSTEMDISPLAYCOMPATIBILITYMODE._serialized_end=9637
  _ESTEAMOSCOMPATIBILITYCATEGORY._serialized_start=9640
  _ESTEAMOSCOMPATIBILITYCATEGORY._serialized_end=9813
  _ESTEAMOSCOMPATIBILITYRESULTDISPLAYTYPE._serialized_start=9816
  _ESTEAMOSCOMPATIBILITYRESULTDISPLAYTYPE._serialized_end=10087
  _ESTEAMDECKCOMPATIBILITYCATEGORY._serialized_start=10090
  _ESTEAMDECKCOMPATIBILITYCATEGORY._serialized_end=10317
  _ESTEAMDECKCOMPATIBILITYRESULTDISPLAYTYPE._serialized_start=10320
  _ESTEAMDECKCOMPATIBILITYRESULTDISPLAYTYPE._serialized_end=10656
  _ESTEAMDECKCOMPATIBILITYTESTRESULT._serialized_start=10659
  _ESTEAMDECKCOMPATIBILITYTESTRESULT._serialized_end=10941
  _EACSTATE._serialized_start=10943
  _EACSTATE._serialized_end=11062
  _EBATTERYSTATE._serialized_start=11065
  _EBATTERYSTATE._serialized_end=11198
  _EOSBRANCH._serialized_start=11201
  _EOSBRANCH._serialized_end=11455
  _EBROWSERGPUSTATUS._serialized_start=11458
  _EBROWSERGPUSTATUS._serialized_end=11912
  _EBROWSERFEATURESTATUS._serialized_start=11915
  _EBROWSERFEATURESTATUS._serialized_end=12526
  _EGPUDRIVERID._serialized_start=12529
  _EGPUDRIVERID._serialized_end=13200
  _ECOMMUNITYITEMCLASS._serialized_start=13203
  _ECOMMUNITYITEMCLASS._serialized_end=13936
  _ESTEAMDECKCOMPATIBILITYFEEDBACK._serialized_start=13939
  _ESTEAMDECKCOMPATIBILITYFEEDBACK._serialized_end=14156
  _EPROVIDEDECKFEEDBACKPREFERENCE._serialized_start=14159
  _EPROVIDEDECKFEEDBACKPREFERENCE._serialized_end=14318
  _ETOUCHGESTURE._serialized_start=14321
  _ETOUCHGESTURE._serialized_end=14754
  _ESESSIONPERSISTENCE._serialized_start=14757
  _ESESSIONPERSISTENCE._serialized_end=14897
  _ENEWSTEAMANNOUNCEMENTSTATE._serialized_start=14900
  _ENEWSTEAMANNOUNCEMENTSTATE._serialized_end=15117
  _EFORUMTYPE._serialized_start=15120
  _EFORUMTYPE._serialized_end=15374
  _ECOMMENTTHREADTYPE._serialized_start=15377
  _ECOMMENTTHREADTYPE._serialized_end=16284
  _EBROADCASTPERMISSION._serialized_start=16287
  _EBROADCASTPERMISSION._serialized_end=16502
  _EBROADCASTENCODERSETTING._serialized_start=16504
  _EBROADCASTENCODERSETTING._serialized_end=16606
  _ECLOUDGAMINGPLATFORM._serialized_start=16608
  _ECLOUDGAMINGPLATFORM._serialized_end=16729
  _ECOMPROMISEDETECTIONTYPE._serialized_start=16732
  _ECOMPROMISEDETECTIONTYPE._serialized_end=17097
  _EASYNCGAMESESSIONUSERSTATE._serialized_start=17100
  _EASYNCGAMESESSIONUSERSTATE._serialized_end=17314
  _EASYNCGAMESESSIONUSERVISIBILITY._serialized_start=17317
  _EASYNCGAMESESSIONUSERVISIBILITY._serialized_end=17513
  _EGAMERECORDINGTYPE._serialized_start=17516
  _EGAMERECORDINGTYPE._serialized_end=17728
  _EEXPORTCODEC._serialized_start=17730
  _EEXPORTCODEC._serialized_end=17822
  _EPROTOAPPTYPE._serialized_start=17825
  _EPROTOAPPTYPE._serialized_end=18315
  _ECHILDPROCESSQUERYCOMMAND._serialized_start=18318
  _ECHILDPROCESSQUERYCOMMAND._serialized_end=18468
  _ECHILDPROCESSQUERYEXITCODE._serialized_start=18471
  _ECHILDPROCESSQUERYEXITCODE._serialized_end=18845
  _EWINDOWSUPDATEINSTALLATIONIMPACT._serialized_start=18848
  _EWINDOWSUPDATEINSTALLATIONIMPACT._serialized_end=19090
  _EWINDOWSUPDATEREBOOTBEHAVIOR._serialized_start=19093
  _EWINDOWSUPDATEREBOOTBEHAVIOR._serialized_end=19335
  _EEXTERNALSALEEVENTTYPE._serialized_start=19338
  _EEXTERNALSALEEVENTTYPE._serialized_end=19592
  _ECONTENTREPORTSUBJECTTYPE._serialized_start=19595
  _ECONTENTREPORTSUBJECTTYPE._serialized_end=19828
  _ECONTENTREPORTREASON._serialized_start=19831
  _ECONTENTREPORTREASON._serialized_end=20177
  _ECONTROLLEDLEGALCATEGORYSTATUS._serialized_start=20180
  _ECONTROLLEDLEGALCATEGORYSTATUS._serialized_end=20397
  _ECONTENTMODERATORLEVEL._serialized_start=20400
  _ECONTENTMODERATORLEVEL._serialized_end=20569
  _ECONTENTREPORTRESOLUTION._serialized_start=20572
  _ECONTENTREPORTRESOLUTION._serialized_end=20802
  _ECONTENTMODERATEDREASON._serialized_start=20805
  _ECONTENTMODERATEDREASON._serialized_end=21021
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: encrypted_app_ticket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65ncrypted_app_ticket.proto\"\xad\x01\n\x12\x45ncryptedAppTicket\x12\x19\n\x11ticket_version_no\x18\x01 \x01(\r\x12\x1b\n\x13\x63rc_encryptedticket\x18\x02 \x01(\r\x12\x1c\n\x14\x63\x62_encrypteduserdata\x18\x03 \x01(\r\x12\'\n\x1f\x63\x62_encrypted_appownershipticket\x18\x04 \x01(\r\x12\x18\n\x10\x65ncrypted_ticket\x18\x05 \x01(\x0c\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'encrypted_app_ticket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ENCRYPTEDAPPTICKET._serialized_start=31
  _ENCRYPTEDAPPTICKET._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_partnerapps.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_partnerapps.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"J\n\'CPartnerApps_RequestUploadToken_Request\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"f\n(CPartnerApps_RequestUploadToken_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x12\n\nrouting_id\x18\x03 \x01(\x04\"]\n!CPartnerApps_FinishUpload_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"H\n(CPartnerApps_FinishUploadKVSign_Response\x12\x1c\n\x14signed_installscript\x18\x01 \x01(\t\"\xa2\x01\n*CPartnerApps_FinishUploadLegacyDRM_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\r\n\x05\x66lags\x18\x04 \x01(\r\x12\x11\n\ttool_name\x18\x05 \x01(\t\x12\x18\n\tuse_cloud\x18\x06 \x01(\x08:\x05\x66\x61lse\">\n+CPartnerApps_FinishUploadLegacyDRM_Response\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\"$\n\"CPartnerApps_FinishUpload_Response\"\x89\x01\n&CPartnerApps_FinishUploadDepot_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x04 \x01(\r\x12\x13\n\x0b\x62uild_flags\x18\x05 \x01(\r\"C\n\'CPartnerApps_FinishUploadDepot_Response\x12\x18\n\x10\x62uild_routing_id\x18\x01 \x01(\x04\"T\n(CPartnerApps_GetDepotBuildResult_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\"S\n)CPartnerApps_GetDepotBuildResult_Response\x12\x13\n\x0bmanifest_id\x18\x01 \x01(\x04\x12\x11\n\terror_msg\x18\x02 \x01(\t\"5\n#CPartnerApps_FindDRMUploads_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\"\xb4\x01\n\x1e\x43PartnerApps_ExistingDRMUpload\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08\x61\x63tor_id\x18\x03 \x01(\x05\x12\x15\n\rsupplied_name\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\r\x12\x10\n\x08mod_type\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x07\x12\x14\n\x0corig_file_id\x18\t \x01(\t\"X\n$CPartnerApps_FindDRMUploads_Response\x12\x30\n\x07uploads\x18\x01 \x03(\x0b\x32\x1f.CPartnerApps_ExistingDRMUpload\"@\n\x1d\x43PartnerApps_Download_Request\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\"F\n\x1e\x43PartnerApps_Download_Response\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\x32\x8d\t\n\x0bPartnerApps\x12o\n\x18RequestKVSignUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12l\n\x15RequestDRMUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12l\n\x15RequestCEGUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12n\n\x17RequestDepotUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\x12\x63\n\x12\x46inishUploadKVSign\x12\".CPartnerApps_FinishUpload_Request\x1a).CPartnerApps_FinishUploadKVSign_Response\x12r\n\x15\x46inishUploadDRMUpload\x12+.CPartnerApps_FinishUploadLegacyDRM_Request\x1a,.CPartnerApps_FinishUploadLegacyDRM_Response\x12`\n\x15\x46inishUploadCEGUpload\x12\".CPartnerApps_FinishUpload_Request\x1a#.CPartnerApps_FinishUpload_Response\x12l\n\x17\x46inishUploadDepotUpload\x12\'.CPartnerApps_FinishUploadDepot_Request\x1a(.CPartnerApps_FinishUploadDepot_Response\x12l\n\x13GetDepotBuildResult\x12).CPartnerApps_GetDepotBuildResult_Request\x1a*.CPartnerApps_GetDepotBuildResult_Response\x12]\n\x0e\x46indDRMUploads\x12$.CPartnerApps_FindDRMUploads_Request\x1a%.CPartnerApps_FindDRMUploads_Response\x12K\n\x08\x44ownload\x12\x1e.CPartnerApps_Download_Request\x1a\x1f.CPartnerApps_Download_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_partnerapps_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST._serialized_start=95
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST._serialized_end=169
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE._serialized_start=171
  _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE._serialized_end=273
  _CPARTNERAPPS_FINISHUPLOAD_REQUEST._serialized_start=275
  _CPARTNERAPPS_FINISHUPLOAD_REQUEST._serialized_end=368
  _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE._serialized_start=370
  _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE._serialized_end=442
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST._serialized_start=445
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST._serialized_end=607
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE._serialized_start=609
  _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE._serialized_end=671
  _CPARTNERAPPS_FINISHUPLOAD_RESPONSE._serialized_start=673
  _CPARTNERAPPS_FINISHUPLOAD_RESPONSE._serialized_end=709
  _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST._serialized_start=712
  _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST._serialized_end=849
  _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE._serialized_start=851
  _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE._serialized_end=918
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST._serialized_start=920
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST._serialized_end=1004
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE._serialized_start=1006
  _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE._serialized_end=1089
  _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST._serialized_start=1091
  _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST._serialized_end=1144
  _CPARTNERAPPS_EXISTINGDRMUPLOAD._serialized_start=1147
  _CPARTNERAPPS_EXISTINGDRMUPLOAD._serialized_end=1327
  _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE._serialized_start=1329
  _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE._serialized_end=1417
  _CPARTNERAPPS_DOWNLOAD_REQUEST._serialized_start=1419
  _CPARTNERAPPS_DOWNLOAD_REQUEST._serialized_end=1483
  _CPARTNERAPPS_DOWNLOAD_RESPONSE._serialized_start=1485
  _CPARTNERAPPS_DOWNLOAD_RESPONSE._serialized_end=1555
  _PARTNERAPPS._serialized_start=1558
  _PARTNERAPPS._serialized_end=2723
_builder.BuildServices(DESCRIPTOR, 'steammessages_partnerapps_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_ufs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_clientserver_ufs.proto\x1a\x18steammessages_base.proto\"D\n\x1a\x43MsgClientUFSGetUGCDetails\x12&\n\x08hcontent\x18\x01 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\"\xe5\x01\n\"CMsgClientUFSGetUGCDetailsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x17\n\x0fsteamid_creator\x18\x05 \x01(\x06\x12\x11\n\tfile_size\x18\x06 \x01(\r\x12\x1c\n\x14\x63ompressed_file_size\x18\x07 \x01(\r\x12\x17\n\x0frangecheck_host\x18\x08 \x01(\t\x12\x19\n\x11\x66ile_encoded_sha1\x18\t \x01(\t\"C\n\x1e\x43MsgClientUFSGetSingleFileInfo\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\xb8\x01\n&CMsgClientUFSGetSingleFileInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x15\n\rraw_file_size\x18\x06 \x01(\r\x12\x1a\n\x12is_explicit_delete\x18\x07 \x01(\x08\";\n\x16\x43MsgClientUFSShareFile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\\\n\x1e\x43MsgClientUFSShareFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12&\n\x08hcontent\x18\x02 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_ufs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTUFSGETUGCDETAILS._serialized_start=66
  _CMSGCLIENTUFSGETUGCDETAILS._serialized_end=134
  _CMSGCLIENTUFSGETUGCDETAILSRESPONSE._serialized_start=137
  _CMSGCLIENTUFSGETUGCDETAILSRESPONSE._serialized_end=366
  _CMSGCLIENTUFSGETSINGLEFILEINFO._serialized_start=368
  _CMSGCLIENTUFSGETSINGLEFILEINFO._serialized_end=435
  _CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE._serialized_start=438
  _CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE._serialized_end=622
  _CMSGCLIENTUFSSHAREFILE._serialized_start=624
  _CMSGCLIENTUFSSHAREFILE._serialized_end=683
  _CMSGCLIENTUFSSHAREFILERESPONSE._serialized_start=685
  _CMSGCLIENTUFSSHAREFILERESPONSE._serialized_end=777
# @@protoc_insertion_point(module_scope)
